(* For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [arm64_const.ml] *)

let _ARM64_SFT_INVALID = 0;;
let _ARM64_SFT_LSL = 1;;
let _ARM64_SFT_MSL = 2;;
let _ARM64_SFT_LSR = 3;;
let _ARM64_SFT_ASR = 4;;
let _ARM64_SFT_ROR = 5;;

let _ARM64_EXT_INVALID = 0;;
let _ARM64_EXT_UXTB = 1;;
let _ARM64_EXT_UXTH = 2;;
let _ARM64_EXT_UXTW = 3;;
let _ARM64_EXT_UXTX = 4;;
let _ARM64_EXT_SXTB = 5;;
let _ARM64_EXT_SXTH = 6;;
let _ARM64_EXT_SXTW = 7;;
let _ARM64_EXT_SXTX = 8;;

let _ARM64_CC_INVALID = 0;;
let _ARM64_CC_EQ = 1;;
let _ARM64_CC_NE = 2;;
let _ARM64_CC_HS = 3;;
let _ARM64_CC_LO = 4;;
let _ARM64_CC_MI = 5;;
let _ARM64_CC_PL = 6;;
let _ARM64_CC_VS = 7;;
let _ARM64_CC_VC = 8;;
let _ARM64_CC_HI = 9;;
let _ARM64_CC_LS = 10;;
let _ARM64_CC_GE = 11;;
let _ARM64_CC_LT = 12;;
let _ARM64_CC_GT = 13;;
let _ARM64_CC_LE = 14;;
let _ARM64_CC_AL = 15;;
let _ARM64_CC_NV = 16;;

let _ARM64_SYSREG_INVALID = 0;;
let _ARM64_SYSREG_ACCDATA_EL1 = 0xC685;;
let _ARM64_SYSREG_ACTLR_EL1 = 0xC081;;
let _ARM64_SYSREG_ACTLR_EL2 = 0xE081;;
let _ARM64_SYSREG_ACTLR_EL3 = 0xF081;;
let _ARM64_SYSREG_AFSR0_EL1 = 0xC288;;
let _ARM64_SYSREG_AFSR0_EL12 = 0xEA88;;
let _ARM64_SYSREG_AFSR0_EL2 = 0xE288;;
let _ARM64_SYSREG_AFSR0_EL3 = 0xF288;;
let _ARM64_SYSREG_AFSR1_EL1 = 0xC289;;
let _ARM64_SYSREG_AFSR1_EL12 = 0xEA89;;
let _ARM64_SYSREG_AFSR1_EL2 = 0xE289;;
let _ARM64_SYSREG_AFSR1_EL3 = 0xF289;;
let _ARM64_SYSREG_AIDR_EL1 = 0xC807;;
let _ARM64_SYSREG_AMAIR_EL1 = 0xC518;;
let _ARM64_SYSREG_AMAIR_EL12 = 0xED18;;
let _ARM64_SYSREG_AMAIR_EL2 = 0xE518;;
let _ARM64_SYSREG_AMAIR_EL3 = 0xF518;;
let _ARM64_SYSREG_AMCFGR_EL0 = 0xDE91;;
let _ARM64_SYSREG_AMCGCR_EL0 = 0xDE92;;
let _ARM64_SYSREG_AMCNTENCLR0_EL0 = 0xDE94;;
let _ARM64_SYSREG_AMCNTENCLR1_EL0 = 0xDE98;;
let _ARM64_SYSREG_AMCNTENSET0_EL0 = 0xDE95;;
let _ARM64_SYSREG_AMCNTENSET1_EL0 = 0xDE99;;
let _ARM64_SYSREG_AMCR_EL0 = 0xDE90;;
let _ARM64_SYSREG_AMEVCNTR00_EL0 = 0xDEA0;;
let _ARM64_SYSREG_AMEVCNTR01_EL0 = 0xDEA1;;
let _ARM64_SYSREG_AMEVCNTR02_EL0 = 0xDEA2;;
let _ARM64_SYSREG_AMEVCNTR03_EL0 = 0xDEA3;;
let _ARM64_SYSREG_AMEVCNTR10_EL0 = 0xDEE0;;
let _ARM64_SYSREG_AMEVCNTR110_EL0 = 0xDEEA;;
let _ARM64_SYSREG_AMEVCNTR111_EL0 = 0xDEEB;;
let _ARM64_SYSREG_AMEVCNTR112_EL0 = 0xDEEC;;
let _ARM64_SYSREG_AMEVCNTR113_EL0 = 0xDEED;;
let _ARM64_SYSREG_AMEVCNTR114_EL0 = 0xDEEE;;
let _ARM64_SYSREG_AMEVCNTR115_EL0 = 0xDEEF;;
let _ARM64_SYSREG_AMEVCNTR11_EL0 = 0xDEE1;;
let _ARM64_SYSREG_AMEVCNTR12_EL0 = 0xDEE2;;
let _ARM64_SYSREG_AMEVCNTR13_EL0 = 0xDEE3;;
let _ARM64_SYSREG_AMEVCNTR14_EL0 = 0xDEE4;;
let _ARM64_SYSREG_AMEVCNTR15_EL0 = 0xDEE5;;
let _ARM64_SYSREG_AMEVCNTR16_EL0 = 0xDEE6;;
let _ARM64_SYSREG_AMEVCNTR17_EL0 = 0xDEE7;;
let _ARM64_SYSREG_AMEVCNTR18_EL0 = 0xDEE8;;
let _ARM64_SYSREG_AMEVCNTR19_EL0 = 0xDEE9;;
let _ARM64_SYSREG_AMEVCNTVOFF00_EL2 = 0xE6C0;;
let _ARM64_SYSREG_AMEVCNTVOFF010_EL2 = 0xE6CA;;
let _ARM64_SYSREG_AMEVCNTVOFF011_EL2 = 0xE6CB;;
let _ARM64_SYSREG_AMEVCNTVOFF012_EL2 = 0xE6CC;;
let _ARM64_SYSREG_AMEVCNTVOFF013_EL2 = 0xE6CD;;
let _ARM64_SYSREG_AMEVCNTVOFF014_EL2 = 0xE6CE;;
let _ARM64_SYSREG_AMEVCNTVOFF015_EL2 = 0xE6CF;;
let _ARM64_SYSREG_AMEVCNTVOFF01_EL2 = 0xE6C1;;
let _ARM64_SYSREG_AMEVCNTVOFF02_EL2 = 0xE6C2;;
let _ARM64_SYSREG_AMEVCNTVOFF03_EL2 = 0xE6C3;;
let _ARM64_SYSREG_AMEVCNTVOFF04_EL2 = 0xE6C4;;
let _ARM64_SYSREG_AMEVCNTVOFF05_EL2 = 0xE6C5;;
let _ARM64_SYSREG_AMEVCNTVOFF06_EL2 = 0xE6C6;;
let _ARM64_SYSREG_AMEVCNTVOFF07_EL2 = 0xE6C7;;
let _ARM64_SYSREG_AMEVCNTVOFF08_EL2 = 0xE6C8;;
let _ARM64_SYSREG_AMEVCNTVOFF09_EL2 = 0xE6C9;;
let _ARM64_SYSREG_AMEVCNTVOFF10_EL2 = 0xE6D0;;
let _ARM64_SYSREG_AMEVCNTVOFF110_EL2 = 0xE6DA;;
let _ARM64_SYSREG_AMEVCNTVOFF111_EL2 = 0xE6DB;;
let _ARM64_SYSREG_AMEVCNTVOFF112_EL2 = 0xE6DC;;
let _ARM64_SYSREG_AMEVCNTVOFF113_EL2 = 0xE6DD;;
let _ARM64_SYSREG_AMEVCNTVOFF114_EL2 = 0xE6DE;;
let _ARM64_SYSREG_AMEVCNTVOFF115_EL2 = 0xE6DF;;
let _ARM64_SYSREG_AMEVCNTVOFF11_EL2 = 0xE6D1;;
let _ARM64_SYSREG_AMEVCNTVOFF12_EL2 = 0xE6D2;;
let _ARM64_SYSREG_AMEVCNTVOFF13_EL2 = 0xE6D3;;
let _ARM64_SYSREG_AMEVCNTVOFF14_EL2 = 0xE6D4;;
let _ARM64_SYSREG_AMEVCNTVOFF15_EL2 = 0xE6D5;;
let _ARM64_SYSREG_AMEVCNTVOFF16_EL2 = 0xE6D6;;
let _ARM64_SYSREG_AMEVCNTVOFF17_EL2 = 0xE6D7;;
let _ARM64_SYSREG_AMEVCNTVOFF18_EL2 = 0xE6D8;;
let _ARM64_SYSREG_AMEVCNTVOFF19_EL2 = 0xE6D9;;
let _ARM64_SYSREG_AMEVTYPER00_EL0 = 0xDEB0;;
let _ARM64_SYSREG_AMEVTYPER01_EL0 = 0xDEB1;;
let _ARM64_SYSREG_AMEVTYPER02_EL0 = 0xDEB2;;
let _ARM64_SYSREG_AMEVTYPER03_EL0 = 0xDEB3;;
let _ARM64_SYSREG_AMEVTYPER10_EL0 = 0xDEF0;;
let _ARM64_SYSREG_AMEVTYPER110_EL0 = 0xDEFA;;
let _ARM64_SYSREG_AMEVTYPER111_EL0 = 0xDEFB;;
let _ARM64_SYSREG_AMEVTYPER112_EL0 = 0xDEFC;;
let _ARM64_SYSREG_AMEVTYPER113_EL0 = 0xDEFD;;
let _ARM64_SYSREG_AMEVTYPER114_EL0 = 0xDEFE;;
let _ARM64_SYSREG_AMEVTYPER115_EL0 = 0xDEFF;;
let _ARM64_SYSREG_AMEVTYPER11_EL0 = 0xDEF1;;
let _ARM64_SYSREG_AMEVTYPER12_EL0 = 0xDEF2;;
let _ARM64_SYSREG_AMEVTYPER13_EL0 = 0xDEF3;;
let _ARM64_SYSREG_AMEVTYPER14_EL0 = 0xDEF4;;
let _ARM64_SYSREG_AMEVTYPER15_EL0 = 0xDEF5;;
let _ARM64_SYSREG_AMEVTYPER16_EL0 = 0xDEF6;;
let _ARM64_SYSREG_AMEVTYPER17_EL0 = 0xDEF7;;
let _ARM64_SYSREG_AMEVTYPER18_EL0 = 0xDEF8;;
let _ARM64_SYSREG_AMEVTYPER19_EL0 = 0xDEF9;;
let _ARM64_SYSREG_AMUSERENR_EL0 = 0xDE93;;
let _ARM64_SYSREG_APDAKEYHI_EL1 = 0xC111;;
let _ARM64_SYSREG_APDAKEYLO_EL1 = 0xC110;;
let _ARM64_SYSREG_APDBKEYHI_EL1 = 0xC113;;
let _ARM64_SYSREG_APDBKEYLO_EL1 = 0xC112;;
let _ARM64_SYSREG_APGAKEYHI_EL1 = 0xC119;;
let _ARM64_SYSREG_APGAKEYLO_EL1 = 0xC118;;
let _ARM64_SYSREG_APIAKEYHI_EL1 = 0xC109;;
let _ARM64_SYSREG_APIAKEYLO_EL1 = 0xC108;;
let _ARM64_SYSREG_APIBKEYHI_EL1 = 0xC10B;;
let _ARM64_SYSREG_APIBKEYLO_EL1 = 0xC10A;;
let _ARM64_SYSREG_BRBCR_EL1 = 0x8C80;;
let _ARM64_SYSREG_BRBCR_EL12 = 0xAC80;;
let _ARM64_SYSREG_BRBCR_EL2 = 0xA480;;
let _ARM64_SYSREG_BRBFCR_EL1 = 0x8C81;;
let _ARM64_SYSREG_BRBIDR0_EL1 = 0x8C90;;
let _ARM64_SYSREG_BRBINF0_EL1 = 0x8C00;;
let _ARM64_SYSREG_BRBINF10_EL1 = 0x8C50;;
let _ARM64_SYSREG_BRBINF11_EL1 = 0x8C58;;
let _ARM64_SYSREG_BRBINF12_EL1 = 0x8C60;;
let _ARM64_SYSREG_BRBINF13_EL1 = 0x8C68;;
let _ARM64_SYSREG_BRBINF14_EL1 = 0x8C70;;
let _ARM64_SYSREG_BRBINF15_EL1 = 0x8C78;;
let _ARM64_SYSREG_BRBINF16_EL1 = 0x8C04;;
let _ARM64_SYSREG_BRBINF17_EL1 = 0x8C0C;;
let _ARM64_SYSREG_BRBINF18_EL1 = 0x8C14;;
let _ARM64_SYSREG_BRBINF19_EL1 = 0x8C1C;;
let _ARM64_SYSREG_BRBINF1_EL1 = 0x8C08;;
let _ARM64_SYSREG_BRBINF20_EL1 = 0x8C24;;
let _ARM64_SYSREG_BRBINF21_EL1 = 0x8C2C;;
let _ARM64_SYSREG_BRBINF22_EL1 = 0x8C34;;
let _ARM64_SYSREG_BRBINF23_EL1 = 0x8C3C;;
let _ARM64_SYSREG_BRBINF24_EL1 = 0x8C44;;
let _ARM64_SYSREG_BRBINF25_EL1 = 0x8C4C;;
let _ARM64_SYSREG_BRBINF26_EL1 = 0x8C54;;
let _ARM64_SYSREG_BRBINF27_EL1 = 0x8C5C;;
let _ARM64_SYSREG_BRBINF28_EL1 = 0x8C64;;
let _ARM64_SYSREG_BRBINF29_EL1 = 0x8C6C;;
let _ARM64_SYSREG_BRBINF2_EL1 = 0x8C10;;
let _ARM64_SYSREG_BRBINF30_EL1 = 0x8C74;;
let _ARM64_SYSREG_BRBINF31_EL1 = 0x8C7C;;
let _ARM64_SYSREG_BRBINF3_EL1 = 0x8C18;;
let _ARM64_SYSREG_BRBINF4_EL1 = 0x8C20;;
let _ARM64_SYSREG_BRBINF5_EL1 = 0x8C28;;
let _ARM64_SYSREG_BRBINF6_EL1 = 0x8C30;;
let _ARM64_SYSREG_BRBINF7_EL1 = 0x8C38;;
let _ARM64_SYSREG_BRBINF8_EL1 = 0x8C40;;
let _ARM64_SYSREG_BRBINF9_EL1 = 0x8C48;;
let _ARM64_SYSREG_BRBINFINJ_EL1 = 0x8C88;;
let _ARM64_SYSREG_BRBSRC0_EL1 = 0x8C01;;
let _ARM64_SYSREG_BRBSRC10_EL1 = 0x8C51;;
let _ARM64_SYSREG_BRBSRC11_EL1 = 0x8C59;;
let _ARM64_SYSREG_BRBSRC12_EL1 = 0x8C61;;
let _ARM64_SYSREG_BRBSRC13_EL1 = 0x8C69;;
let _ARM64_SYSREG_BRBSRC14_EL1 = 0x8C71;;
let _ARM64_SYSREG_BRBSRC15_EL1 = 0x8C79;;
let _ARM64_SYSREG_BRBSRC16_EL1 = 0x8C05;;
let _ARM64_SYSREG_BRBSRC17_EL1 = 0x8C0D;;
let _ARM64_SYSREG_BRBSRC18_EL1 = 0x8C15;;
let _ARM64_SYSREG_BRBSRC19_EL1 = 0x8C1D;;
let _ARM64_SYSREG_BRBSRC1_EL1 = 0x8C09;;
let _ARM64_SYSREG_BRBSRC20_EL1 = 0x8C25;;
let _ARM64_SYSREG_BRBSRC21_EL1 = 0x8C2D;;
let _ARM64_SYSREG_BRBSRC22_EL1 = 0x8C35;;
let _ARM64_SYSREG_BRBSRC23_EL1 = 0x8C3D;;
let _ARM64_SYSREG_BRBSRC24_EL1 = 0x8C45;;
let _ARM64_SYSREG_BRBSRC25_EL1 = 0x8C4D;;
let _ARM64_SYSREG_BRBSRC26_EL1 = 0x8C55;;
let _ARM64_SYSREG_BRBSRC27_EL1 = 0x8C5D;;
let _ARM64_SYSREG_BRBSRC28_EL1 = 0x8C65;;
let _ARM64_SYSREG_BRBSRC29_EL1 = 0x8C6D;;
let _ARM64_SYSREG_BRBSRC2_EL1 = 0x8C11;;
let _ARM64_SYSREG_BRBSRC30_EL1 = 0x8C75;;
let _ARM64_SYSREG_BRBSRC31_EL1 = 0x8C7D;;
let _ARM64_SYSREG_BRBSRC3_EL1 = 0x8C19;;
let _ARM64_SYSREG_BRBSRC4_EL1 = 0x8C21;;
let _ARM64_SYSREG_BRBSRC5_EL1 = 0x8C29;;
let _ARM64_SYSREG_BRBSRC6_EL1 = 0x8C31;;
let _ARM64_SYSREG_BRBSRC7_EL1 = 0x8C39;;
let _ARM64_SYSREG_BRBSRC8_EL1 = 0x8C41;;
let _ARM64_SYSREG_BRBSRC9_EL1 = 0x8C49;;
let _ARM64_SYSREG_BRBSRCINJ_EL1 = 0x8C89;;
let _ARM64_SYSREG_BRBTGT0_EL1 = 0x8C02;;
let _ARM64_SYSREG_BRBTGT10_EL1 = 0x8C52;;
let _ARM64_SYSREG_BRBTGT11_EL1 = 0x8C5A;;
let _ARM64_SYSREG_BRBTGT12_EL1 = 0x8C62;;
let _ARM64_SYSREG_BRBTGT13_EL1 = 0x8C6A;;
let _ARM64_SYSREG_BRBTGT14_EL1 = 0x8C72;;
let _ARM64_SYSREG_BRBTGT15_EL1 = 0x8C7A;;
let _ARM64_SYSREG_BRBTGT16_EL1 = 0x8C06;;
let _ARM64_SYSREG_BRBTGT17_EL1 = 0x8C0E;;
let _ARM64_SYSREG_BRBTGT18_EL1 = 0x8C16;;
let _ARM64_SYSREG_BRBTGT19_EL1 = 0x8C1E;;
let _ARM64_SYSREG_BRBTGT1_EL1 = 0x8C0A;;
let _ARM64_SYSREG_BRBTGT20_EL1 = 0x8C26;;
let _ARM64_SYSREG_BRBTGT21_EL1 = 0x8C2E;;
let _ARM64_SYSREG_BRBTGT22_EL1 = 0x8C36;;
let _ARM64_SYSREG_BRBTGT23_EL1 = 0x8C3E;;
let _ARM64_SYSREG_BRBTGT24_EL1 = 0x8C46;;
let _ARM64_SYSREG_BRBTGT25_EL1 = 0x8C4E;;
let _ARM64_SYSREG_BRBTGT26_EL1 = 0x8C56;;
let _ARM64_SYSREG_BRBTGT27_EL1 = 0x8C5E;;
let _ARM64_SYSREG_BRBTGT28_EL1 = 0x8C66;;
let _ARM64_SYSREG_BRBTGT29_EL1 = 0x8C6E;;
let _ARM64_SYSREG_BRBTGT2_EL1 = 0x8C12;;
let _ARM64_SYSREG_BRBTGT30_EL1 = 0x8C76;;
let _ARM64_SYSREG_BRBTGT31_EL1 = 0x8C7E;;
let _ARM64_SYSREG_BRBTGT3_EL1 = 0x8C1A;;
let _ARM64_SYSREG_BRBTGT4_EL1 = 0x8C22;;
let _ARM64_SYSREG_BRBTGT5_EL1 = 0x8C2A;;
let _ARM64_SYSREG_BRBTGT6_EL1 = 0x8C32;;
let _ARM64_SYSREG_BRBTGT7_EL1 = 0x8C3A;;
let _ARM64_SYSREG_BRBTGT8_EL1 = 0x8C42;;
let _ARM64_SYSREG_BRBTGT9_EL1 = 0x8C4A;;
let _ARM64_SYSREG_BRBTGTINJ_EL1 = 0x8C8A;;
let _ARM64_SYSREG_BRBTS_EL1 = 0x8C82;;
let _ARM64_SYSREG_CCSIDR2_EL1 = 0xC802;;
let _ARM64_SYSREG_CCSIDR_EL1 = 0xC800;;
let _ARM64_SYSREG_CLIDR_EL1 = 0xC801;;
let _ARM64_SYSREG_CNTFRQ_EL0 = 0xDF00;;
let _ARM64_SYSREG_CNTHCTL_EL2 = 0xE708;;
let _ARM64_SYSREG_CNTHPS_CTL_EL2 = 0xE729;;
let _ARM64_SYSREG_CNTHPS_CVAL_EL2 = 0xE72A;;
let _ARM64_SYSREG_CNTHPS_TVAL_EL2 = 0xE728;;
let _ARM64_SYSREG_CNTHP_CTL_EL2 = 0xE711;;
let _ARM64_SYSREG_CNTHP_CVAL_EL2 = 0xE712;;
let _ARM64_SYSREG_CNTHP_TVAL_EL2 = 0xE710;;
let _ARM64_SYSREG_CNTHVS_CTL_EL2 = 0xE721;;
let _ARM64_SYSREG_CNTHVS_CVAL_EL2 = 0xE722;;
let _ARM64_SYSREG_CNTHVS_TVAL_EL2 = 0xE720;;
let _ARM64_SYSREG_CNTHV_CTL_EL2 = 0xE719;;
let _ARM64_SYSREG_CNTHV_CVAL_EL2 = 0xE71A;;
let _ARM64_SYSREG_CNTHV_TVAL_EL2 = 0xE718;;
let _ARM64_SYSREG_CNTISCALE_EL2 = 0xE705;;
let _ARM64_SYSREG_CNTKCTL_EL1 = 0xC708;;
let _ARM64_SYSREG_CNTKCTL_EL12 = 0xEF08;;
let _ARM64_SYSREG_CNTPCTSS_EL0 = 0xDF05;;
let _ARM64_SYSREG_CNTPCT_EL0 = 0xDF01;;
let _ARM64_SYSREG_CNTPOFF_EL2 = 0xE706;;
let _ARM64_SYSREG_CNTPS_CTL_EL1 = 0xFF11;;
let _ARM64_SYSREG_CNTPS_CVAL_EL1 = 0xFF12;;
let _ARM64_SYSREG_CNTPS_TVAL_EL1 = 0xFF10;;
let _ARM64_SYSREG_CNTP_CTL_EL0 = 0xDF11;;
let _ARM64_SYSREG_CNTP_CTL_EL02 = 0xEF11;;
let _ARM64_SYSREG_CNTP_CVAL_EL0 = 0xDF12;;
let _ARM64_SYSREG_CNTP_CVAL_EL02 = 0xEF12;;
let _ARM64_SYSREG_CNTP_TVAL_EL0 = 0xDF10;;
let _ARM64_SYSREG_CNTP_TVAL_EL02 = 0xEF10;;
let _ARM64_SYSREG_CNTSCALE_EL2 = 0xE704;;
let _ARM64_SYSREG_CNTVCTSS_EL0 = 0xDF06;;
let _ARM64_SYSREG_CNTVCT_EL0 = 0xDF02;;
let _ARM64_SYSREG_CNTVFRQ_EL2 = 0xE707;;
let _ARM64_SYSREG_CNTVOFF_EL2 = 0xE703;;
let _ARM64_SYSREG_CNTV_CTL_EL0 = 0xDF19;;
let _ARM64_SYSREG_CNTV_CTL_EL02 = 0xEF19;;
let _ARM64_SYSREG_CNTV_CVAL_EL0 = 0xDF1A;;
let _ARM64_SYSREG_CNTV_CVAL_EL02 = 0xEF1A;;
let _ARM64_SYSREG_CNTV_TVAL_EL0 = 0xDF18;;
let _ARM64_SYSREG_CNTV_TVAL_EL02 = 0xEF18;;
let _ARM64_SYSREG_CONTEXTIDR_EL1 = 0xC681;;
let _ARM64_SYSREG_CONTEXTIDR_EL12 = 0xEE81;;
let _ARM64_SYSREG_CONTEXTIDR_EL2 = 0xE681;;
let _ARM64_SYSREG_CPACR_EL1 = 0xC082;;
let _ARM64_SYSREG_CPACR_EL12 = 0xE882;;
let _ARM64_SYSREG_CPM_IOACC_CTL_EL3 = 0xFF90;;
let _ARM64_SYSREG_CPTR_EL2 = 0xE08A;;
let _ARM64_SYSREG_CPTR_EL3 = 0xF08A;;
let _ARM64_SYSREG_CSSELR_EL1 = 0xD000;;
let _ARM64_SYSREG_CTR_EL0 = 0xD801;;
let _ARM64_SYSREG_CURRENTEL = 0xC212;;
let _ARM64_SYSREG_DACR32_EL2 = 0xE180;;
let _ARM64_SYSREG_DAIF = 0xDA11;;
let _ARM64_SYSREG_DBGAUTHSTATUS_EL1 = 0x83F6;;
let _ARM64_SYSREG_DBGBCR0_EL1 = 0x8005;;
let _ARM64_SYSREG_DBGBCR10_EL1 = 0x8055;;
let _ARM64_SYSREG_DBGBCR11_EL1 = 0x805D;;
let _ARM64_SYSREG_DBGBCR12_EL1 = 0x8065;;
let _ARM64_SYSREG_DBGBCR13_EL1 = 0x806D;;
let _ARM64_SYSREG_DBGBCR14_EL1 = 0x8075;;
let _ARM64_SYSREG_DBGBCR15_EL1 = 0x807D;;
let _ARM64_SYSREG_DBGBCR1_EL1 = 0x800D;;
let _ARM64_SYSREG_DBGBCR2_EL1 = 0x8015;;
let _ARM64_SYSREG_DBGBCR3_EL1 = 0x801D;;
let _ARM64_SYSREG_DBGBCR4_EL1 = 0x8025;;
let _ARM64_SYSREG_DBGBCR5_EL1 = 0x802D;;
let _ARM64_SYSREG_DBGBCR6_EL1 = 0x8035;;
let _ARM64_SYSREG_DBGBCR7_EL1 = 0x803D;;
let _ARM64_SYSREG_DBGBCR8_EL1 = 0x8045;;
let _ARM64_SYSREG_DBGBCR9_EL1 = 0x804D;;
let _ARM64_SYSREG_DBGBVR0_EL1 = 0x8004;;
let _ARM64_SYSREG_DBGBVR10_EL1 = 0x8054;;
let _ARM64_SYSREG_DBGBVR11_EL1 = 0x805C;;
let _ARM64_SYSREG_DBGBVR12_EL1 = 0x8064;;
let _ARM64_SYSREG_DBGBVR13_EL1 = 0x806C;;
let _ARM64_SYSREG_DBGBVR14_EL1 = 0x8074;;
let _ARM64_SYSREG_DBGBVR15_EL1 = 0x807C;;
let _ARM64_SYSREG_DBGBVR1_EL1 = 0x800C;;
let _ARM64_SYSREG_DBGBVR2_EL1 = 0x8014;;
let _ARM64_SYSREG_DBGBVR3_EL1 = 0x801C;;
let _ARM64_SYSREG_DBGBVR4_EL1 = 0x8024;;
let _ARM64_SYSREG_DBGBVR5_EL1 = 0x802C;;
let _ARM64_SYSREG_DBGBVR6_EL1 = 0x8034;;
let _ARM64_SYSREG_DBGBVR7_EL1 = 0x803C;;
let _ARM64_SYSREG_DBGBVR8_EL1 = 0x8044;;
let _ARM64_SYSREG_DBGBVR9_EL1 = 0x804C;;
let _ARM64_SYSREG_DBGCLAIMCLR_EL1 = 0x83CE;;
let _ARM64_SYSREG_DBGCLAIMSET_EL1 = 0x83C6;;
let _ARM64_SYSREG_DBGDTRRX_EL0 = 0x9828;;
let _ARM64_SYSREG_DBGDTRTX_EL0 = 0x9828;;
let _ARM64_SYSREG_DBGDTR_EL0 = 0x9820;;
let _ARM64_SYSREG_DBGPRCR_EL1 = 0x80A4;;
let _ARM64_SYSREG_DBGVCR32_EL2 = 0xA038;;
let _ARM64_SYSREG_DBGWCR0_EL1 = 0x8007;;
let _ARM64_SYSREG_DBGWCR10_EL1 = 0x8057;;
let _ARM64_SYSREG_DBGWCR11_EL1 = 0x805F;;
let _ARM64_SYSREG_DBGWCR12_EL1 = 0x8067;;
let _ARM64_SYSREG_DBGWCR13_EL1 = 0x806F;;
let _ARM64_SYSREG_DBGWCR14_EL1 = 0x8077;;
let _ARM64_SYSREG_DBGWCR15_EL1 = 0x807F;;
let _ARM64_SYSREG_DBGWCR1_EL1 = 0x800F;;
let _ARM64_SYSREG_DBGWCR2_EL1 = 0x8017;;
let _ARM64_SYSREG_DBGWCR3_EL1 = 0x801F;;
let _ARM64_SYSREG_DBGWCR4_EL1 = 0x8027;;
let _ARM64_SYSREG_DBGWCR5_EL1 = 0x802F;;
let _ARM64_SYSREG_DBGWCR6_EL1 = 0x8037;;
let _ARM64_SYSREG_DBGWCR7_EL1 = 0x803F;;
let _ARM64_SYSREG_DBGWCR8_EL1 = 0x8047;;
let _ARM64_SYSREG_DBGWCR9_EL1 = 0x804F;;
let _ARM64_SYSREG_DBGWVR0_EL1 = 0x8006;;
let _ARM64_SYSREG_DBGWVR10_EL1 = 0x8056;;
let _ARM64_SYSREG_DBGWVR11_EL1 = 0x805E;;
let _ARM64_SYSREG_DBGWVR12_EL1 = 0x8066;;
let _ARM64_SYSREG_DBGWVR13_EL1 = 0x806E;;
let _ARM64_SYSREG_DBGWVR14_EL1 = 0x8076;;
let _ARM64_SYSREG_DBGWVR15_EL1 = 0x807E;;
let _ARM64_SYSREG_DBGWVR1_EL1 = 0x800E;;
let _ARM64_SYSREG_DBGWVR2_EL1 = 0x8016;;
let _ARM64_SYSREG_DBGWVR3_EL1 = 0x801E;;
let _ARM64_SYSREG_DBGWVR4_EL1 = 0x8026;;
let _ARM64_SYSREG_DBGWVR5_EL1 = 0x802E;;
let _ARM64_SYSREG_DBGWVR6_EL1 = 0x8036;;
let _ARM64_SYSREG_DBGWVR7_EL1 = 0x803E;;
let _ARM64_SYSREG_DBGWVR8_EL1 = 0x8046;;
let _ARM64_SYSREG_DBGWVR9_EL1 = 0x804E;;
let _ARM64_SYSREG_DCZID_EL0 = 0xD807;;
let _ARM64_SYSREG_DISR_EL1 = 0xC609;;
let _ARM64_SYSREG_DIT = 0xDA15;;
let _ARM64_SYSREG_DLR_EL0 = 0xDA29;;
let _ARM64_SYSREG_DSPSR_EL0 = 0xDA28;;
let _ARM64_SYSREG_ELR_EL1 = 0xC201;;
let _ARM64_SYSREG_ELR_EL12 = 0xEA01;;
let _ARM64_SYSREG_ELR_EL2 = 0xE201;;
let _ARM64_SYSREG_ELR_EL3 = 0xF201;;
let _ARM64_SYSREG_ERRIDR_EL1 = 0xC298;;
let _ARM64_SYSREG_ERRSELR_EL1 = 0xC299;;
let _ARM64_SYSREG_ERXADDR_EL1 = 0xC2A3;;
let _ARM64_SYSREG_ERXCTLR_EL1 = 0xC2A1;;
let _ARM64_SYSREG_ERXFR_EL1 = 0xC2A0;;
let _ARM64_SYSREG_ERXMISC0_EL1 = 0xC2A8;;
let _ARM64_SYSREG_ERXMISC1_EL1 = 0xC2A9;;
let _ARM64_SYSREG_ERXMISC2_EL1 = 0xC2AA;;
let _ARM64_SYSREG_ERXMISC3_EL1 = 0xC2AB;;
let _ARM64_SYSREG_ERXPFGCDN_EL1 = 0xC2A6;;
let _ARM64_SYSREG_ERXPFGCTL_EL1 = 0xC2A5;;
let _ARM64_SYSREG_ERXPFGF_EL1 = 0xC2A4;;
let _ARM64_SYSREG_ERXSTATUS_EL1 = 0xC2A2;;
let _ARM64_SYSREG_ESR_EL1 = 0xC290;;
let _ARM64_SYSREG_ESR_EL12 = 0xEA90;;
let _ARM64_SYSREG_ESR_EL2 = 0xE290;;
let _ARM64_SYSREG_ESR_EL3 = 0xF290;;
let _ARM64_SYSREG_FAR_EL1 = 0xC300;;
let _ARM64_SYSREG_FAR_EL12 = 0xEB00;;
let _ARM64_SYSREG_FAR_EL2 = 0xE300;;
let _ARM64_SYSREG_FAR_EL3 = 0xF300;;
let _ARM64_SYSREG_FPCR = 0xDA20;;
let _ARM64_SYSREG_FPEXC32_EL2 = 0xE298;;
let _ARM64_SYSREG_FPSR = 0xDA21;;
let _ARM64_SYSREG_GCR_EL1 = 0xC086;;
let _ARM64_SYSREG_GMID_EL1 = 0xC804;;
let _ARM64_SYSREG_GPCCR_EL3 = 0xF10E;;
let _ARM64_SYSREG_GPTBR_EL3 = 0xF10C;;
let _ARM64_SYSREG_HACR_EL2 = 0xE08F;;
let _ARM64_SYSREG_HCRX_EL2 = 0xE092;;
let _ARM64_SYSREG_HCR_EL2 = 0xE088;;
let _ARM64_SYSREG_HDFGRTR_EL2 = 0xE18C;;
let _ARM64_SYSREG_HDFGWTR_EL2 = 0xE18D;;
let _ARM64_SYSREG_HFGITR_EL2 = 0xE08E;;
let _ARM64_SYSREG_HFGRTR_EL2 = 0xE08C;;
let _ARM64_SYSREG_HFGWTR_EL2 = 0xE08D;;
let _ARM64_SYSREG_HPFAR_EL2 = 0xE304;;
let _ARM64_SYSREG_HSTR_EL2 = 0xE08B;;
let _ARM64_SYSREG_ICC_AP0R0_EL1 = 0xC644;;
let _ARM64_SYSREG_ICC_AP0R1_EL1 = 0xC645;;
let _ARM64_SYSREG_ICC_AP0R2_EL1 = 0xC646;;
let _ARM64_SYSREG_ICC_AP0R3_EL1 = 0xC647;;
let _ARM64_SYSREG_ICC_AP1R0_EL1 = 0xC648;;
let _ARM64_SYSREG_ICC_AP1R1_EL1 = 0xC649;;
let _ARM64_SYSREG_ICC_AP1R2_EL1 = 0xC64A;;
let _ARM64_SYSREG_ICC_AP1R3_EL1 = 0xC64B;;
let _ARM64_SYSREG_ICC_ASGI1R_EL1 = 0xC65E;;
let _ARM64_SYSREG_ICC_BPR0_EL1 = 0xC643;;
let _ARM64_SYSREG_ICC_BPR1_EL1 = 0xC663;;
let _ARM64_SYSREG_ICC_CTLR_EL1 = 0xC664;;
let _ARM64_SYSREG_ICC_CTLR_EL3 = 0xF664;;
let _ARM64_SYSREG_ICC_DIR_EL1 = 0xC659;;
let _ARM64_SYSREG_ICC_EOIR0_EL1 = 0xC641;;
let _ARM64_SYSREG_ICC_EOIR1_EL1 = 0xC661;;
let _ARM64_SYSREG_ICC_HPPIR0_EL1 = 0xC642;;
let _ARM64_SYSREG_ICC_HPPIR1_EL1 = 0xC662;;
let _ARM64_SYSREG_ICC_IAR0_EL1 = 0xC640;;
let _ARM64_SYSREG_ICC_IAR1_EL1 = 0xC660;;
let _ARM64_SYSREG_ICC_IGRPEN0_EL1 = 0xC666;;
let _ARM64_SYSREG_ICC_IGRPEN1_EL1 = 0xC667;;
let _ARM64_SYSREG_ICC_IGRPEN1_EL3 = 0xF667;;
let _ARM64_SYSREG_ICC_PMR_EL1 = 0xC230;;
let _ARM64_SYSREG_ICC_RPR_EL1 = 0xC65B;;
let _ARM64_SYSREG_ICC_SGI0R_EL1 = 0xC65F;;
let _ARM64_SYSREG_ICC_SGI1R_EL1 = 0xC65D;;
let _ARM64_SYSREG_ICC_SRE_EL1 = 0xC665;;
let _ARM64_SYSREG_ICC_SRE_EL2 = 0xE64D;;
let _ARM64_SYSREG_ICC_SRE_EL3 = 0xF665;;
let _ARM64_SYSREG_ICH_AP0R0_EL2 = 0xE640;;
let _ARM64_SYSREG_ICH_AP0R1_EL2 = 0xE641;;
let _ARM64_SYSREG_ICH_AP0R2_EL2 = 0xE642;;
let _ARM64_SYSREG_ICH_AP0R3_EL2 = 0xE643;;
let _ARM64_SYSREG_ICH_AP1R0_EL2 = 0xE648;;
let _ARM64_SYSREG_ICH_AP1R1_EL2 = 0xE649;;
let _ARM64_SYSREG_ICH_AP1R2_EL2 = 0xE64A;;
let _ARM64_SYSREG_ICH_AP1R3_EL2 = 0xE64B;;
let _ARM64_SYSREG_ICH_EISR_EL2 = 0xE65B;;
let _ARM64_SYSREG_ICH_ELRSR_EL2 = 0xE65D;;
let _ARM64_SYSREG_ICH_HCR_EL2 = 0xE658;;
let _ARM64_SYSREG_ICH_LR0_EL2 = 0xE660;;
let _ARM64_SYSREG_ICH_LR10_EL2 = 0xE66A;;
let _ARM64_SYSREG_ICH_LR11_EL2 = 0xE66B;;
let _ARM64_SYSREG_ICH_LR12_EL2 = 0xE66C;;
let _ARM64_SYSREG_ICH_LR13_EL2 = 0xE66D;;
let _ARM64_SYSREG_ICH_LR14_EL2 = 0xE66E;;
let _ARM64_SYSREG_ICH_LR15_EL2 = 0xE66F;;
let _ARM64_SYSREG_ICH_LR1_EL2 = 0xE661;;
let _ARM64_SYSREG_ICH_LR2_EL2 = 0xE662;;
let _ARM64_SYSREG_ICH_LR3_EL2 = 0xE663;;
let _ARM64_SYSREG_ICH_LR4_EL2 = 0xE664;;
let _ARM64_SYSREG_ICH_LR5_EL2 = 0xE665;;
let _ARM64_SYSREG_ICH_LR6_EL2 = 0xE666;;
let _ARM64_SYSREG_ICH_LR7_EL2 = 0xE667;;
let _ARM64_SYSREG_ICH_LR8_EL2 = 0xE668;;
let _ARM64_SYSREG_ICH_LR9_EL2 = 0xE669;;
let _ARM64_SYSREG_ICH_MISR_EL2 = 0xE65A;;
let _ARM64_SYSREG_ICH_VMCR_EL2 = 0xE65F;;
let _ARM64_SYSREG_ICH_VTR_EL2 = 0xE659;;
let _ARM64_SYSREG_ID_AA64AFR0_EL1 = 0xC02C;;
let _ARM64_SYSREG_ID_AA64AFR1_EL1 = 0xC02D;;
let _ARM64_SYSREG_ID_AA64DFR0_EL1 = 0xC028;;
let _ARM64_SYSREG_ID_AA64DFR1_EL1 = 0xC029;;
let _ARM64_SYSREG_ID_AA64ISAR0_EL1 = 0xC030;;
let _ARM64_SYSREG_ID_AA64ISAR1_EL1 = 0xC031;;
let _ARM64_SYSREG_ID_AA64ISAR2_EL1 = 0xC032;;
let _ARM64_SYSREG_ID_AA64MMFR0_EL1 = 0xC038;;
let _ARM64_SYSREG_ID_AA64MMFR1_EL1 = 0xC039;;
let _ARM64_SYSREG_ID_AA64MMFR2_EL1 = 0xC03A;;
let _ARM64_SYSREG_ID_AA64PFR0_EL1 = 0xC020;;
let _ARM64_SYSREG_ID_AA64PFR1_EL1 = 0xC021;;
let _ARM64_SYSREG_ID_AA64SMFR0_EL1 = 0xC025;;
let _ARM64_SYSREG_ID_AA64ZFR0_EL1 = 0xC024;;
let _ARM64_SYSREG_ID_AFR0_EL1 = 0xC00B;;
let _ARM64_SYSREG_ID_DFR0_EL1 = 0xC00A;;
let _ARM64_SYSREG_ID_ISAR0_EL1 = 0xC010;;
let _ARM64_SYSREG_ID_ISAR1_EL1 = 0xC011;;
let _ARM64_SYSREG_ID_ISAR2_EL1 = 0xC012;;
let _ARM64_SYSREG_ID_ISAR3_EL1 = 0xC013;;
let _ARM64_SYSREG_ID_ISAR4_EL1 = 0xC014;;
let _ARM64_SYSREG_ID_ISAR5_EL1 = 0xC015;;
let _ARM64_SYSREG_ID_ISAR6_EL1 = 0xC017;;
let _ARM64_SYSREG_ID_MMFR0_EL1 = 0xC00C;;
let _ARM64_SYSREG_ID_MMFR1_EL1 = 0xC00D;;
let _ARM64_SYSREG_ID_MMFR2_EL1 = 0xC00E;;
let _ARM64_SYSREG_ID_MMFR3_EL1 = 0xC00F;;
let _ARM64_SYSREG_ID_MMFR4_EL1 = 0xC016;;
let _ARM64_SYSREG_ID_MMFR5_EL1 = 0xC01E;;
let _ARM64_SYSREG_ID_PFR0_EL1 = 0xC008;;
let _ARM64_SYSREG_ID_PFR1_EL1 = 0xC009;;
let _ARM64_SYSREG_ID_PFR2_EL1 = 0xC01C;;
let _ARM64_SYSREG_IFSR32_EL2 = 0xE281;;
let _ARM64_SYSREG_ISR_EL1 = 0xC608;;
let _ARM64_SYSREG_LORC_EL1 = 0xC523;;
let _ARM64_SYSREG_LOREA_EL1 = 0xC521;;
let _ARM64_SYSREG_LORID_EL1 = 0xC527;;
let _ARM64_SYSREG_LORN_EL1 = 0xC522;;
let _ARM64_SYSREG_LORSA_EL1 = 0xC520;;
let _ARM64_SYSREG_MAIR_EL1 = 0xC510;;
let _ARM64_SYSREG_MAIR_EL12 = 0xED10;;
let _ARM64_SYSREG_MAIR_EL2 = 0xE510;;
let _ARM64_SYSREG_MAIR_EL3 = 0xF510;;
let _ARM64_SYSREG_MDCCINT_EL1 = 0x8010;;
let _ARM64_SYSREG_MDCCSR_EL0 = 0x9808;;
let _ARM64_SYSREG_MDCR_EL2 = 0xE089;;
let _ARM64_SYSREG_MDCR_EL3 = 0xF099;;
let _ARM64_SYSREG_MDRAR_EL1 = 0x8080;;
let _ARM64_SYSREG_MDSCR_EL1 = 0x8012;;
let _ARM64_SYSREG_MFAR_EL3 = 0xF305;;
let _ARM64_SYSREG_MIDR_EL1 = 0xC000;;
let _ARM64_SYSREG_MPAM0_EL1 = 0xC529;;
let _ARM64_SYSREG_MPAM1_EL1 = 0xC528;;
let _ARM64_SYSREG_MPAM1_EL12 = 0xED28;;
let _ARM64_SYSREG_MPAM2_EL2 = 0xE528;;
let _ARM64_SYSREG_MPAM3_EL3 = 0xF528;;
let _ARM64_SYSREG_MPAMHCR_EL2 = 0xE520;;
let _ARM64_SYSREG_MPAMIDR_EL1 = 0xC524;;
let _ARM64_SYSREG_MPAMSM_EL1 = 0xC52B;;
let _ARM64_SYSREG_MPAMVPM0_EL2 = 0xE530;;
let _ARM64_SYSREG_MPAMVPM1_EL2 = 0xE531;;
let _ARM64_SYSREG_MPAMVPM2_EL2 = 0xE532;;
let _ARM64_SYSREG_MPAMVPM3_EL2 = 0xE533;;
let _ARM64_SYSREG_MPAMVPM4_EL2 = 0xE534;;
let _ARM64_SYSREG_MPAMVPM5_EL2 = 0xE535;;
let _ARM64_SYSREG_MPAMVPM6_EL2 = 0xE536;;
let _ARM64_SYSREG_MPAMVPM7_EL2 = 0xE537;;
let _ARM64_SYSREG_MPAMVPMV_EL2 = 0xE521;;
let _ARM64_SYSREG_MPIDR_EL1 = 0xC005;;
let _ARM64_SYSREG_MPUIR_EL1 = 0xC004;;
let _ARM64_SYSREG_MPUIR_EL2 = 0xE004;;
let _ARM64_SYSREG_MVFR0_EL1 = 0xC018;;
let _ARM64_SYSREG_MVFR1_EL1 = 0xC019;;
let _ARM64_SYSREG_MVFR2_EL1 = 0xC01A;;
let _ARM64_SYSREG_NZCV = 0xDA10;;
let _ARM64_SYSREG_OSDLR_EL1 = 0x809C;;
let _ARM64_SYSREG_OSDTRRX_EL1 = 0x8002;;
let _ARM64_SYSREG_OSDTRTX_EL1 = 0x801A;;
let _ARM64_SYSREG_OSECCR_EL1 = 0x8032;;
let _ARM64_SYSREG_OSLAR_EL1 = 0x8084;;
let _ARM64_SYSREG_OSLSR_EL1 = 0x808C;;
let _ARM64_SYSREG_PAN = 0xC213;;
let _ARM64_SYSREG_PAR_EL1 = 0xC3A0;;
let _ARM64_SYSREG_PMBIDR_EL1 = 0xC4D7;;
let _ARM64_SYSREG_PMBLIMITR_EL1 = 0xC4D0;;
let _ARM64_SYSREG_PMBPTR_EL1 = 0xC4D1;;
let _ARM64_SYSREG_PMBSR_EL1 = 0xC4D3;;
let _ARM64_SYSREG_PMCCFILTR_EL0 = 0xDF7F;;
let _ARM64_SYSREG_PMCCNTR_EL0 = 0xDCE8;;
let _ARM64_SYSREG_PMCEID0_EL0 = 0xDCE6;;
let _ARM64_SYSREG_PMCEID1_EL0 = 0xDCE7;;
let _ARM64_SYSREG_PMCNTENCLR_EL0 = 0xDCE2;;
let _ARM64_SYSREG_PMCNTENSET_EL0 = 0xDCE1;;
let _ARM64_SYSREG_PMCR_EL0 = 0xDCE0;;
let _ARM64_SYSREG_PMEVCNTR0_EL0 = 0xDF40;;
let _ARM64_SYSREG_PMEVCNTR10_EL0 = 0xDF4A;;
let _ARM64_SYSREG_PMEVCNTR11_EL0 = 0xDF4B;;
let _ARM64_SYSREG_PMEVCNTR12_EL0 = 0xDF4C;;
let _ARM64_SYSREG_PMEVCNTR13_EL0 = 0xDF4D;;
let _ARM64_SYSREG_PMEVCNTR14_EL0 = 0xDF4E;;
let _ARM64_SYSREG_PMEVCNTR15_EL0 = 0xDF4F;;
let _ARM64_SYSREG_PMEVCNTR16_EL0 = 0xDF50;;
let _ARM64_SYSREG_PMEVCNTR17_EL0 = 0xDF51;;
let _ARM64_SYSREG_PMEVCNTR18_EL0 = 0xDF52;;
let _ARM64_SYSREG_PMEVCNTR19_EL0 = 0xDF53;;
let _ARM64_SYSREG_PMEVCNTR1_EL0 = 0xDF41;;
let _ARM64_SYSREG_PMEVCNTR20_EL0 = 0xDF54;;
let _ARM64_SYSREG_PMEVCNTR21_EL0 = 0xDF55;;
let _ARM64_SYSREG_PMEVCNTR22_EL0 = 0xDF56;;
let _ARM64_SYSREG_PMEVCNTR23_EL0 = 0xDF57;;
let _ARM64_SYSREG_PMEVCNTR24_EL0 = 0xDF58;;
let _ARM64_SYSREG_PMEVCNTR25_EL0 = 0xDF59;;
let _ARM64_SYSREG_PMEVCNTR26_EL0 = 0xDF5A;;
let _ARM64_SYSREG_PMEVCNTR27_EL0 = 0xDF5B;;
let _ARM64_SYSREG_PMEVCNTR28_EL0 = 0xDF5C;;
let _ARM64_SYSREG_PMEVCNTR29_EL0 = 0xDF5D;;
let _ARM64_SYSREG_PMEVCNTR2_EL0 = 0xDF42;;
let _ARM64_SYSREG_PMEVCNTR30_EL0 = 0xDF5E;;
let _ARM64_SYSREG_PMEVCNTR3_EL0 = 0xDF43;;
let _ARM64_SYSREG_PMEVCNTR4_EL0 = 0xDF44;;
let _ARM64_SYSREG_PMEVCNTR5_EL0 = 0xDF45;;
let _ARM64_SYSREG_PMEVCNTR6_EL0 = 0xDF46;;
let _ARM64_SYSREG_PMEVCNTR7_EL0 = 0xDF47;;
let _ARM64_SYSREG_PMEVCNTR8_EL0 = 0xDF48;;
let _ARM64_SYSREG_PMEVCNTR9_EL0 = 0xDF49;;
let _ARM64_SYSREG_PMEVTYPER0_EL0 = 0xDF60;;
let _ARM64_SYSREG_PMEVTYPER10_EL0 = 0xDF6A;;
let _ARM64_SYSREG_PMEVTYPER11_EL0 = 0xDF6B;;
let _ARM64_SYSREG_PMEVTYPER12_EL0 = 0xDF6C;;
let _ARM64_SYSREG_PMEVTYPER13_EL0 = 0xDF6D;;
let _ARM64_SYSREG_PMEVTYPER14_EL0 = 0xDF6E;;
let _ARM64_SYSREG_PMEVTYPER15_EL0 = 0xDF6F;;
let _ARM64_SYSREG_PMEVTYPER16_EL0 = 0xDF70;;
let _ARM64_SYSREG_PMEVTYPER17_EL0 = 0xDF71;;
let _ARM64_SYSREG_PMEVTYPER18_EL0 = 0xDF72;;
let _ARM64_SYSREG_PMEVTYPER19_EL0 = 0xDF73;;
let _ARM64_SYSREG_PMEVTYPER1_EL0 = 0xDF61;;
let _ARM64_SYSREG_PMEVTYPER20_EL0 = 0xDF74;;
let _ARM64_SYSREG_PMEVTYPER21_EL0 = 0xDF75;;
let _ARM64_SYSREG_PMEVTYPER22_EL0 = 0xDF76;;
let _ARM64_SYSREG_PMEVTYPER23_EL0 = 0xDF77;;
let _ARM64_SYSREG_PMEVTYPER24_EL0 = 0xDF78;;
let _ARM64_SYSREG_PMEVTYPER25_EL0 = 0xDF79;;
let _ARM64_SYSREG_PMEVTYPER26_EL0 = 0xDF7A;;
let _ARM64_SYSREG_PMEVTYPER27_EL0 = 0xDF7B;;
let _ARM64_SYSREG_PMEVTYPER28_EL0 = 0xDF7C;;
let _ARM64_SYSREG_PMEVTYPER29_EL0 = 0xDF7D;;
let _ARM64_SYSREG_PMEVTYPER2_EL0 = 0xDF62;;
let _ARM64_SYSREG_PMEVTYPER30_EL0 = 0xDF7E;;
let _ARM64_SYSREG_PMEVTYPER3_EL0 = 0xDF63;;
let _ARM64_SYSREG_PMEVTYPER4_EL0 = 0xDF64;;
let _ARM64_SYSREG_PMEVTYPER5_EL0 = 0xDF65;;
let _ARM64_SYSREG_PMEVTYPER6_EL0 = 0xDF66;;
let _ARM64_SYSREG_PMEVTYPER7_EL0 = 0xDF67;;
let _ARM64_SYSREG_PMEVTYPER8_EL0 = 0xDF68;;
let _ARM64_SYSREG_PMEVTYPER9_EL0 = 0xDF69;;
let _ARM64_SYSREG_PMINTENCLR_EL1 = 0xC4F2;;
let _ARM64_SYSREG_PMINTENSET_EL1 = 0xC4F1;;
let _ARM64_SYSREG_PMMIR_EL1 = 0xC4F6;;
let _ARM64_SYSREG_PMOVSCLR_EL0 = 0xDCE3;;
let _ARM64_SYSREG_PMOVSSET_EL0 = 0xDCF3;;
let _ARM64_SYSREG_PMSCR_EL1 = 0xC4C8;;
let _ARM64_SYSREG_PMSCR_EL12 = 0xECC8;;
let _ARM64_SYSREG_PMSCR_EL2 = 0xE4C8;;
let _ARM64_SYSREG_PMSELR_EL0 = 0xDCE5;;
let _ARM64_SYSREG_PMSEVFR_EL1 = 0xC4CD;;
let _ARM64_SYSREG_PMSFCR_EL1 = 0xC4CC;;
let _ARM64_SYSREG_PMSICR_EL1 = 0xC4CA;;
let _ARM64_SYSREG_PMSIDR_EL1 = 0xC4CF;;
let _ARM64_SYSREG_PMSIRR_EL1 = 0xC4CB;;
let _ARM64_SYSREG_PMSLATFR_EL1 = 0xC4CE;;
let _ARM64_SYSREG_PMSNEVFR_EL1 = 0xC4C9;;
let _ARM64_SYSREG_PMSWINC_EL0 = 0xDCE4;;
let _ARM64_SYSREG_PMUSERENR_EL0 = 0xDCF0;;
let _ARM64_SYSREG_PMXEVCNTR_EL0 = 0xDCEA;;
let _ARM64_SYSREG_PMXEVTYPER_EL0 = 0xDCE9;;
let _ARM64_SYSREG_PRBAR10_EL1 = 0xC368;;
let _ARM64_SYSREG_PRBAR10_EL2 = 0xE368;;
let _ARM64_SYSREG_PRBAR11_EL1 = 0xC36C;;
let _ARM64_SYSREG_PRBAR11_EL2 = 0xE36C;;
let _ARM64_SYSREG_PRBAR12_EL1 = 0xC370;;
let _ARM64_SYSREG_PRBAR12_EL2 = 0xE370;;
let _ARM64_SYSREG_PRBAR13_EL1 = 0xC374;;
let _ARM64_SYSREG_PRBAR13_EL2 = 0xE374;;
let _ARM64_SYSREG_PRBAR14_EL1 = 0xC378;;
let _ARM64_SYSREG_PRBAR14_EL2 = 0xE378;;
let _ARM64_SYSREG_PRBAR15_EL1 = 0xC37C;;
let _ARM64_SYSREG_PRBAR15_EL2 = 0xE37C;;
let _ARM64_SYSREG_PRBAR1_EL1 = 0xC344;;
let _ARM64_SYSREG_PRBAR1_EL2 = 0xE344;;
let _ARM64_SYSREG_PRBAR2_EL1 = 0xC348;;
let _ARM64_SYSREG_PRBAR2_EL2 = 0xE348;;
let _ARM64_SYSREG_PRBAR3_EL1 = 0xC34C;;
let _ARM64_SYSREG_PRBAR3_EL2 = 0xE34C;;
let _ARM64_SYSREG_PRBAR4_EL1 = 0xC350;;
let _ARM64_SYSREG_PRBAR4_EL2 = 0xE350;;
let _ARM64_SYSREG_PRBAR5_EL1 = 0xC354;;
let _ARM64_SYSREG_PRBAR5_EL2 = 0xE354;;
let _ARM64_SYSREG_PRBAR6_EL1 = 0xC358;;
let _ARM64_SYSREG_PRBAR6_EL2 = 0xE358;;
let _ARM64_SYSREG_PRBAR7_EL1 = 0xC35C;;
let _ARM64_SYSREG_PRBAR7_EL2 = 0xE35C;;
let _ARM64_SYSREG_PRBAR8_EL1 = 0xC360;;
let _ARM64_SYSREG_PRBAR8_EL2 = 0xE360;;
let _ARM64_SYSREG_PRBAR9_EL1 = 0xC364;;
let _ARM64_SYSREG_PRBAR9_EL2 = 0xE364;;
let _ARM64_SYSREG_PRBAR_EL1 = 0xC340;;
let _ARM64_SYSREG_PRBAR_EL2 = 0xE340;;
let _ARM64_SYSREG_PRENR_EL1 = 0xC309;;
let _ARM64_SYSREG_PRENR_EL2 = 0xE309;;
let _ARM64_SYSREG_PRLAR10_EL1 = 0xC369;;
let _ARM64_SYSREG_PRLAR10_EL2 = 0xE369;;
let _ARM64_SYSREG_PRLAR11_EL1 = 0xC36D;;
let _ARM64_SYSREG_PRLAR11_EL2 = 0xE36D;;
let _ARM64_SYSREG_PRLAR12_EL1 = 0xC371;;
let _ARM64_SYSREG_PRLAR12_EL2 = 0xE371;;
let _ARM64_SYSREG_PRLAR13_EL1 = 0xC375;;
let _ARM64_SYSREG_PRLAR13_EL2 = 0xE375;;
let _ARM64_SYSREG_PRLAR14_EL1 = 0xC379;;
let _ARM64_SYSREG_PRLAR14_EL2 = 0xE379;;
let _ARM64_SYSREG_PRLAR15_EL1 = 0xC37D;;
let _ARM64_SYSREG_PRLAR15_EL2 = 0xE37D;;
let _ARM64_SYSREG_PRLAR1_EL1 = 0xC345;;
let _ARM64_SYSREG_PRLAR1_EL2 = 0xE345;;
let _ARM64_SYSREG_PRLAR2_EL1 = 0xC349;;
let _ARM64_SYSREG_PRLAR2_EL2 = 0xE349;;
let _ARM64_SYSREG_PRLAR3_EL1 = 0xC34D;;
let _ARM64_SYSREG_PRLAR3_EL2 = 0xE34D;;
let _ARM64_SYSREG_PRLAR4_EL1 = 0xC351;;
let _ARM64_SYSREG_PRLAR4_EL2 = 0xE351;;
let _ARM64_SYSREG_PRLAR5_EL1 = 0xC355;;
let _ARM64_SYSREG_PRLAR5_EL2 = 0xE355;;
let _ARM64_SYSREG_PRLAR6_EL1 = 0xC359;;
let _ARM64_SYSREG_PRLAR6_EL2 = 0xE359;;
let _ARM64_SYSREG_PRLAR7_EL1 = 0xC35D;;
let _ARM64_SYSREG_PRLAR7_EL2 = 0xE35D;;
let _ARM64_SYSREG_PRLAR8_EL1 = 0xC361;;
let _ARM64_SYSREG_PRLAR8_EL2 = 0xE361;;
let _ARM64_SYSREG_PRLAR9_EL1 = 0xC365;;
let _ARM64_SYSREG_PRLAR9_EL2 = 0xE365;;
let _ARM64_SYSREG_PRLAR_EL1 = 0xC341;;
let _ARM64_SYSREG_PRLAR_EL2 = 0xE341;;
let _ARM64_SYSREG_PRSELR_EL1 = 0xC311;;
let _ARM64_SYSREG_PRSELR_EL2 = 0xE311;;
let _ARM64_SYSREG_REVIDR_EL1 = 0xC006;;
let _ARM64_SYSREG_RGSR_EL1 = 0xC085;;
let _ARM64_SYSREG_RMR_EL1 = 0xC602;;
let _ARM64_SYSREG_RMR_EL2 = 0xE602;;
let _ARM64_SYSREG_RMR_EL3 = 0xF602;;
let _ARM64_SYSREG_RNDR = 0xD920;;
let _ARM64_SYSREG_RNDRRS = 0xD921;;
let _ARM64_SYSREG_RVBAR_EL1 = 0xC601;;
let _ARM64_SYSREG_RVBAR_EL2 = 0xE601;;
let _ARM64_SYSREG_RVBAR_EL3 = 0xF601;;
let _ARM64_SYSREG_SCR_EL3 = 0xF088;;
let _ARM64_SYSREG_SCTLR_EL1 = 0xC080;;
let _ARM64_SYSREG_SCTLR_EL12 = 0xE880;;
let _ARM64_SYSREG_SCTLR_EL2 = 0xE080;;
let _ARM64_SYSREG_SCTLR_EL3 = 0xF080;;
let _ARM64_SYSREG_SCXTNUM_EL0 = 0xDE87;;
let _ARM64_SYSREG_SCXTNUM_EL1 = 0xC687;;
let _ARM64_SYSREG_SCXTNUM_EL12 = 0xEE87;;
let _ARM64_SYSREG_SCXTNUM_EL2 = 0xE687;;
let _ARM64_SYSREG_SCXTNUM_EL3 = 0xF687;;
let _ARM64_SYSREG_SDER32_EL2 = 0xE099;;
let _ARM64_SYSREG_SDER32_EL3 = 0xF089;;
let _ARM64_SYSREG_SMCR_EL1 = 0xC096;;
let _ARM64_SYSREG_SMCR_EL12 = 0xE896;;
let _ARM64_SYSREG_SMCR_EL2 = 0xE096;;
let _ARM64_SYSREG_SMCR_EL3 = 0xF096;;
let _ARM64_SYSREG_SMIDR_EL1 = 0xC806;;
let _ARM64_SYSREG_SMPRIMAP_EL2 = 0xE095;;
let _ARM64_SYSREG_SMPRI_EL1 = 0xC094;;
let _ARM64_SYSREG_SPSEL = 0xC210;;
let _ARM64_SYSREG_SPSR_ABT = 0xE219;;
let _ARM64_SYSREG_SPSR_EL1 = 0xC200;;
let _ARM64_SYSREG_SPSR_EL12 = 0xEA00;;
let _ARM64_SYSREG_SPSR_EL2 = 0xE200;;
let _ARM64_SYSREG_SPSR_EL3 = 0xF200;;
let _ARM64_SYSREG_SPSR_FIQ = 0xE21B;;
let _ARM64_SYSREG_SPSR_IRQ = 0xE218;;
let _ARM64_SYSREG_SPSR_UND = 0xE21A;;
let _ARM64_SYSREG_SP_EL0 = 0xC208;;
let _ARM64_SYSREG_SP_EL1 = 0xE208;;
let _ARM64_SYSREG_SP_EL2 = 0xF208;;
let _ARM64_SYSREG_SSBS = 0xDA16;;
let _ARM64_SYSREG_SVCR = 0xDA12;;
let _ARM64_SYSREG_TCO = 0xDA17;;
let _ARM64_SYSREG_TCR_EL1 = 0xC102;;
let _ARM64_SYSREG_TCR_EL12 = 0xE902;;
let _ARM64_SYSREG_TCR_EL2 = 0xE102;;
let _ARM64_SYSREG_TCR_EL3 = 0xF102;;
let _ARM64_SYSREG_TEECR32_EL1 = 0x9000;;
let _ARM64_SYSREG_TEEHBR32_EL1 = 0x9080;;
let _ARM64_SYSREG_TFSRE0_EL1 = 0xC2B1;;
let _ARM64_SYSREG_TFSR_EL1 = 0xC2B0;;
let _ARM64_SYSREG_TFSR_EL12 = 0xEAB0;;
let _ARM64_SYSREG_TFSR_EL2 = 0xE2B0;;
let _ARM64_SYSREG_TFSR_EL3 = 0xF2B0;;
let _ARM64_SYSREG_TPIDR2_EL0 = 0xDE85;;
let _ARM64_SYSREG_TPIDRRO_EL0 = 0xDE83;;
let _ARM64_SYSREG_TPIDR_EL0 = 0xDE82;;
let _ARM64_SYSREG_TPIDR_EL1 = 0xC684;;
let _ARM64_SYSREG_TPIDR_EL2 = 0xE682;;
let _ARM64_SYSREG_TPIDR_EL3 = 0xF682;;
let _ARM64_SYSREG_TRBBASER_EL1 = 0xC4DA;;
let _ARM64_SYSREG_TRBIDR_EL1 = 0xC4DF;;
let _ARM64_SYSREG_TRBLIMITR_EL1 = 0xC4D8;;
let _ARM64_SYSREG_TRBMAR_EL1 = 0xC4DC;;
let _ARM64_SYSREG_TRBPTR_EL1 = 0xC4D9;;
let _ARM64_SYSREG_TRBSR_EL1 = 0xC4DB;;
let _ARM64_SYSREG_TRBTRG_EL1 = 0xC4DE;;
let _ARM64_SYSREG_TRCACATR0 = 0x8902;;
let _ARM64_SYSREG_TRCACATR1 = 0x8912;;
let _ARM64_SYSREG_TRCACATR10 = 0x8923;;
let _ARM64_SYSREG_TRCACATR11 = 0x8933;;
let _ARM64_SYSREG_TRCACATR12 = 0x8943;;
let _ARM64_SYSREG_TRCACATR13 = 0x8953;;
let _ARM64_SYSREG_TRCACATR14 = 0x8963;;
let _ARM64_SYSREG_TRCACATR15 = 0x8973;;
let _ARM64_SYSREG_TRCACATR2 = 0x8922;;
let _ARM64_SYSREG_TRCACATR3 = 0x8932;;
let _ARM64_SYSREG_TRCACATR4 = 0x8942;;
let _ARM64_SYSREG_TRCACATR5 = 0x8952;;
let _ARM64_SYSREG_TRCACATR6 = 0x8962;;
let _ARM64_SYSREG_TRCACATR7 = 0x8972;;
let _ARM64_SYSREG_TRCACATR8 = 0x8903;;
let _ARM64_SYSREG_TRCACATR9 = 0x8913;;
let _ARM64_SYSREG_TRCACVR0 = 0x8900;;
let _ARM64_SYSREG_TRCACVR1 = 0x8910;;
let _ARM64_SYSREG_TRCACVR10 = 0x8921;;
let _ARM64_SYSREG_TRCACVR11 = 0x8931;;
let _ARM64_SYSREG_TRCACVR12 = 0x8941;;
let _ARM64_SYSREG_TRCACVR13 = 0x8951;;
let _ARM64_SYSREG_TRCACVR14 = 0x8961;;
let _ARM64_SYSREG_TRCACVR15 = 0x8971;;
let _ARM64_SYSREG_TRCACVR2 = 0x8920;;
let _ARM64_SYSREG_TRCACVR3 = 0x8930;;
let _ARM64_SYSREG_TRCACVR4 = 0x8940;;
let _ARM64_SYSREG_TRCACVR5 = 0x8950;;
let _ARM64_SYSREG_TRCACVR6 = 0x8960;;
let _ARM64_SYSREG_TRCACVR7 = 0x8970;;
let _ARM64_SYSREG_TRCACVR8 = 0x8901;;
let _ARM64_SYSREG_TRCACVR9 = 0x8911;;
let _ARM64_SYSREG_TRCAUTHSTATUS = 0x8BF6;;
let _ARM64_SYSREG_TRCAUXCTLR = 0x8830;;
let _ARM64_SYSREG_TRCBBCTLR = 0x8878;;
let _ARM64_SYSREG_TRCCCCTLR = 0x8870;;
let _ARM64_SYSREG_TRCCIDCCTLR0 = 0x8982;;
let _ARM64_SYSREG_TRCCIDCCTLR1 = 0x898A;;
let _ARM64_SYSREG_TRCCIDCVR0 = 0x8980;;
let _ARM64_SYSREG_TRCCIDCVR1 = 0x8990;;
let _ARM64_SYSREG_TRCCIDCVR2 = 0x89A0;;
let _ARM64_SYSREG_TRCCIDCVR3 = 0x89B0;;
let _ARM64_SYSREG_TRCCIDCVR4 = 0x89C0;;
let _ARM64_SYSREG_TRCCIDCVR5 = 0x89D0;;
let _ARM64_SYSREG_TRCCIDCVR6 = 0x89E0;;
let _ARM64_SYSREG_TRCCIDCVR7 = 0x89F0;;
let _ARM64_SYSREG_TRCCIDR0 = 0x8BE7;;
let _ARM64_SYSREG_TRCCIDR1 = 0x8BEF;;
let _ARM64_SYSREG_TRCCIDR2 = 0x8BF7;;
let _ARM64_SYSREG_TRCCIDR3 = 0x8BFF;;
let _ARM64_SYSREG_TRCCLAIMCLR = 0x8BCE;;
let _ARM64_SYSREG_TRCCLAIMSET = 0x8BC6;;
let _ARM64_SYSREG_TRCCNTCTLR0 = 0x8825;;
let _ARM64_SYSREG_TRCCNTCTLR1 = 0x882D;;
let _ARM64_SYSREG_TRCCNTCTLR2 = 0x8835;;
let _ARM64_SYSREG_TRCCNTCTLR3 = 0x883D;;
let _ARM64_SYSREG_TRCCNTRLDVR0 = 0x8805;;
let _ARM64_SYSREG_TRCCNTRLDVR1 = 0x880D;;
let _ARM64_SYSREG_TRCCNTRLDVR2 = 0x8815;;
let _ARM64_SYSREG_TRCCNTRLDVR3 = 0x881D;;
let _ARM64_SYSREG_TRCCNTVR0 = 0x8845;;
let _ARM64_SYSREG_TRCCNTVR1 = 0x884D;;
let _ARM64_SYSREG_TRCCNTVR2 = 0x8855;;
let _ARM64_SYSREG_TRCCNTVR3 = 0x885D;;
let _ARM64_SYSREG_TRCCONFIGR = 0x8820;;
let _ARM64_SYSREG_TRCDEVAFF0 = 0x8BD6;;
let _ARM64_SYSREG_TRCDEVAFF1 = 0x8BDE;;
let _ARM64_SYSREG_TRCDEVARCH = 0x8BFE;;
let _ARM64_SYSREG_TRCDEVID = 0x8B97;;
let _ARM64_SYSREG_TRCDEVTYPE = 0x8B9F;;
let _ARM64_SYSREG_TRCDVCMR0 = 0x8906;;
let _ARM64_SYSREG_TRCDVCMR1 = 0x8926;;
let _ARM64_SYSREG_TRCDVCMR2 = 0x8946;;
let _ARM64_SYSREG_TRCDVCMR3 = 0x8966;;
let _ARM64_SYSREG_TRCDVCMR4 = 0x8907;;
let _ARM64_SYSREG_TRCDVCMR5 = 0x8927;;
let _ARM64_SYSREG_TRCDVCMR6 = 0x8947;;
let _ARM64_SYSREG_TRCDVCMR7 = 0x8967;;
let _ARM64_SYSREG_TRCDVCVR0 = 0x8904;;
let _ARM64_SYSREG_TRCDVCVR1 = 0x8924;;
let _ARM64_SYSREG_TRCDVCVR2 = 0x8944;;
let _ARM64_SYSREG_TRCDVCVR3 = 0x8964;;
let _ARM64_SYSREG_TRCDVCVR4 = 0x8905;;
let _ARM64_SYSREG_TRCDVCVR5 = 0x8925;;
let _ARM64_SYSREG_TRCDVCVR6 = 0x8945;;
let _ARM64_SYSREG_TRCDVCVR7 = 0x8965;;
let _ARM64_SYSREG_TRCEVENTCTL0R = 0x8840;;
let _ARM64_SYSREG_TRCEVENTCTL1R = 0x8848;;
let _ARM64_SYSREG_TRCEXTINSELR = 0x8844;;
let _ARM64_SYSREG_TRCEXTINSELR0 = 0x8844;;
let _ARM64_SYSREG_TRCEXTINSELR1 = 0x884C;;
let _ARM64_SYSREG_TRCEXTINSELR2 = 0x8854;;
let _ARM64_SYSREG_TRCEXTINSELR3 = 0x885C;;
let _ARM64_SYSREG_TRCIDR0 = 0x8847;;
let _ARM64_SYSREG_TRCIDR1 = 0x884F;;
let _ARM64_SYSREG_TRCIDR10 = 0x8816;;
let _ARM64_SYSREG_TRCIDR11 = 0x881E;;
let _ARM64_SYSREG_TRCIDR12 = 0x8826;;
let _ARM64_SYSREG_TRCIDR13 = 0x882E;;
let _ARM64_SYSREG_TRCIDR2 = 0x8857;;
let _ARM64_SYSREG_TRCIDR3 = 0x885F;;
let _ARM64_SYSREG_TRCIDR4 = 0x8867;;
let _ARM64_SYSREG_TRCIDR5 = 0x886F;;
let _ARM64_SYSREG_TRCIDR6 = 0x8877;;
let _ARM64_SYSREG_TRCIDR7 = 0x887F;;
let _ARM64_SYSREG_TRCIDR8 = 0x8806;;
let _ARM64_SYSREG_TRCIDR9 = 0x880E;;
let _ARM64_SYSREG_TRCIMSPEC0 = 0x8807;;
let _ARM64_SYSREG_TRCIMSPEC1 = 0x880F;;
let _ARM64_SYSREG_TRCIMSPEC2 = 0x8817;;
let _ARM64_SYSREG_TRCIMSPEC3 = 0x881F;;
let _ARM64_SYSREG_TRCIMSPEC4 = 0x8827;;
let _ARM64_SYSREG_TRCIMSPEC5 = 0x882F;;
let _ARM64_SYSREG_TRCIMSPEC6 = 0x8837;;
let _ARM64_SYSREG_TRCIMSPEC7 = 0x883F;;
let _ARM64_SYSREG_TRCITCTRL = 0x8B84;;
let _ARM64_SYSREG_TRCLAR = 0x8BE6;;
let _ARM64_SYSREG_TRCLSR = 0x8BEE;;
let _ARM64_SYSREG_TRCOSLAR = 0x8884;;
let _ARM64_SYSREG_TRCOSLSR = 0x888C;;
let _ARM64_SYSREG_TRCPDCR = 0x88A4;;
let _ARM64_SYSREG_TRCPDSR = 0x88AC;;
let _ARM64_SYSREG_TRCPIDR0 = 0x8BC7;;
let _ARM64_SYSREG_TRCPIDR1 = 0x8BCF;;
let _ARM64_SYSREG_TRCPIDR2 = 0x8BD7;;
let _ARM64_SYSREG_TRCPIDR3 = 0x8BDF;;
let _ARM64_SYSREG_TRCPIDR4 = 0x8BA7;;
let _ARM64_SYSREG_TRCPIDR5 = 0x8BAF;;
let _ARM64_SYSREG_TRCPIDR6 = 0x8BB7;;
let _ARM64_SYSREG_TRCPIDR7 = 0x8BBF;;
let _ARM64_SYSREG_TRCPRGCTLR = 0x8808;;
let _ARM64_SYSREG_TRCPROCSELR = 0x8810;;
let _ARM64_SYSREG_TRCQCTLR = 0x8809;;
let _ARM64_SYSREG_TRCRSCTLR10 = 0x88D0;;
let _ARM64_SYSREG_TRCRSCTLR11 = 0x88D8;;
let _ARM64_SYSREG_TRCRSCTLR12 = 0x88E0;;
let _ARM64_SYSREG_TRCRSCTLR13 = 0x88E8;;
let _ARM64_SYSREG_TRCRSCTLR14 = 0x88F0;;
let _ARM64_SYSREG_TRCRSCTLR15 = 0x88F8;;
let _ARM64_SYSREG_TRCRSCTLR16 = 0x8881;;
let _ARM64_SYSREG_TRCRSCTLR17 = 0x8889;;
let _ARM64_SYSREG_TRCRSCTLR18 = 0x8891;;
let _ARM64_SYSREG_TRCRSCTLR19 = 0x8899;;
let _ARM64_SYSREG_TRCRSCTLR2 = 0x8890;;
let _ARM64_SYSREG_TRCRSCTLR20 = 0x88A1;;
let _ARM64_SYSREG_TRCRSCTLR21 = 0x88A9;;
let _ARM64_SYSREG_TRCRSCTLR22 = 0x88B1;;
let _ARM64_SYSREG_TRCRSCTLR23 = 0x88B9;;
let _ARM64_SYSREG_TRCRSCTLR24 = 0x88C1;;
let _ARM64_SYSREG_TRCRSCTLR25 = 0x88C9;;
let _ARM64_SYSREG_TRCRSCTLR26 = 0x88D1;;
let _ARM64_SYSREG_TRCRSCTLR27 = 0x88D9;;
let _ARM64_SYSREG_TRCRSCTLR28 = 0x88E1;;
let _ARM64_SYSREG_TRCRSCTLR29 = 0x88E9;;
let _ARM64_SYSREG_TRCRSCTLR3 = 0x8898;;
let _ARM64_SYSREG_TRCRSCTLR30 = 0x88F1;;
let _ARM64_SYSREG_TRCRSCTLR31 = 0x88F9;;
let _ARM64_SYSREG_TRCRSCTLR4 = 0x88A0;;
let _ARM64_SYSREG_TRCRSCTLR5 = 0x88A8;;
let _ARM64_SYSREG_TRCRSCTLR6 = 0x88B0;;
let _ARM64_SYSREG_TRCRSCTLR7 = 0x88B8;;
let _ARM64_SYSREG_TRCRSCTLR8 = 0x88C0;;
let _ARM64_SYSREG_TRCRSCTLR9 = 0x88C8;;
let _ARM64_SYSREG_TRCRSR = 0x8850;;
let _ARM64_SYSREG_TRCSEQEVR0 = 0x8804;;
let _ARM64_SYSREG_TRCSEQEVR1 = 0x880C;;
let _ARM64_SYSREG_TRCSEQEVR2 = 0x8814;;
let _ARM64_SYSREG_TRCSEQRSTEVR = 0x8834;;
let _ARM64_SYSREG_TRCSEQSTR = 0x883C;;
let _ARM64_SYSREG_TRCSSCCR0 = 0x8882;;
let _ARM64_SYSREG_TRCSSCCR1 = 0x888A;;
let _ARM64_SYSREG_TRCSSCCR2 = 0x8892;;
let _ARM64_SYSREG_TRCSSCCR3 = 0x889A;;
let _ARM64_SYSREG_TRCSSCCR4 = 0x88A2;;
let _ARM64_SYSREG_TRCSSCCR5 = 0x88AA;;
let _ARM64_SYSREG_TRCSSCCR6 = 0x88B2;;
let _ARM64_SYSREG_TRCSSCCR7 = 0x88BA;;
let _ARM64_SYSREG_TRCSSCSR0 = 0x88C2;;
let _ARM64_SYSREG_TRCSSCSR1 = 0x88CA;;
let _ARM64_SYSREG_TRCSSCSR2 = 0x88D2;;
let _ARM64_SYSREG_TRCSSCSR3 = 0x88DA;;
let _ARM64_SYSREG_TRCSSCSR4 = 0x88E2;;
let _ARM64_SYSREG_TRCSSCSR5 = 0x88EA;;
let _ARM64_SYSREG_TRCSSCSR6 = 0x88F2;;
let _ARM64_SYSREG_TRCSSCSR7 = 0x88FA;;
let _ARM64_SYSREG_TRCSSPCICR0 = 0x8883;;
let _ARM64_SYSREG_TRCSSPCICR1 = 0x888B;;
let _ARM64_SYSREG_TRCSSPCICR2 = 0x8893;;
let _ARM64_SYSREG_TRCSSPCICR3 = 0x889B;;
let _ARM64_SYSREG_TRCSSPCICR4 = 0x88A3;;
let _ARM64_SYSREG_TRCSSPCICR5 = 0x88AB;;
let _ARM64_SYSREG_TRCSSPCICR6 = 0x88B3;;
let _ARM64_SYSREG_TRCSSPCICR7 = 0x88BB;;
let _ARM64_SYSREG_TRCSTALLCTLR = 0x8858;;
let _ARM64_SYSREG_TRCSTATR = 0x8818;;
let _ARM64_SYSREG_TRCSYNCPR = 0x8868;;
let _ARM64_SYSREG_TRCTRACEIDR = 0x8801;;
let _ARM64_SYSREG_TRCTSCTLR = 0x8860;;
let _ARM64_SYSREG_TRCVDARCCTLR = 0x8852;;
let _ARM64_SYSREG_TRCVDCTLR = 0x8842;;
let _ARM64_SYSREG_TRCVDSACCTLR = 0x884A;;
let _ARM64_SYSREG_TRCVICTLR = 0x8802;;
let _ARM64_SYSREG_TRCVIIECTLR = 0x880A;;
let _ARM64_SYSREG_TRCVIPCSSCTLR = 0x881A;;
let _ARM64_SYSREG_TRCVISSCTLR = 0x8812;;
let _ARM64_SYSREG_TRCVMIDCCTLR0 = 0x8992;;
let _ARM64_SYSREG_TRCVMIDCCTLR1 = 0x899A;;
let _ARM64_SYSREG_TRCVMIDCVR0 = 0x8981;;
let _ARM64_SYSREG_TRCVMIDCVR1 = 0x8991;;
let _ARM64_SYSREG_TRCVMIDCVR2 = 0x89A1;;
let _ARM64_SYSREG_TRCVMIDCVR3 = 0x89B1;;
let _ARM64_SYSREG_TRCVMIDCVR4 = 0x89C1;;
let _ARM64_SYSREG_TRCVMIDCVR5 = 0x89D1;;
let _ARM64_SYSREG_TRCVMIDCVR6 = 0x89E1;;
let _ARM64_SYSREG_TRCVMIDCVR7 = 0x89F1;;
let _ARM64_SYSREG_TRFCR_EL1 = 0xC091;;
let _ARM64_SYSREG_TRFCR_EL12 = 0xE891;;
let _ARM64_SYSREG_TRFCR_EL2 = 0xE091;;
let _ARM64_SYSREG_TTBR0_EL1 = 0xC100;;
let _ARM64_SYSREG_TTBR0_EL12 = 0xE900;;
let _ARM64_SYSREG_TTBR0_EL2 = 0xE100;;
let _ARM64_SYSREG_TTBR0_EL3 = 0xF100;;
let _ARM64_SYSREG_TTBR1_EL1 = 0xC101;;
let _ARM64_SYSREG_TTBR1_EL12 = 0xE901;;
let _ARM64_SYSREG_TTBR1_EL2 = 0xE101;;
let _ARM64_SYSREG_UAO = 0xC214;;
let _ARM64_SYSREG_VBAR_EL1 = 0xC600;;
let _ARM64_SYSREG_VBAR_EL12 = 0xEE00;;
let _ARM64_SYSREG_VBAR_EL2 = 0xE600;;
let _ARM64_SYSREG_VBAR_EL3 = 0xF600;;
let _ARM64_SYSREG_VDISR_EL2 = 0xE609;;
let _ARM64_SYSREG_VMPIDR_EL2 = 0xE005;;
let _ARM64_SYSREG_VNCR_EL2 = 0xE110;;
let _ARM64_SYSREG_VPIDR_EL2 = 0xE000;;
let _ARM64_SYSREG_VSCTLR_EL2 = 0xE100;;
let _ARM64_SYSREG_VSESR_EL2 = 0xE293;;
let _ARM64_SYSREG_VSTCR_EL2 = 0xE132;;
let _ARM64_SYSREG_VSTTBR_EL2 = 0xE130;;
let _ARM64_SYSREG_VTCR_EL2 = 0xE10A;;
let _ARM64_SYSREG_VTTBR_EL2 = 0xE108;;
let _ARM64_SYSREG_ZCR_EL1 = 0xC090;;
let _ARM64_SYSREG_ZCR_EL12 = 0xE890;;
let _ARM64_SYSREG_ZCR_EL2 = 0xE090;;
let _ARM64_SYSREG_ZCR_EL3 = 0xF090;;

let _ARM64_PSTATE_INVALID = 0;;
let _ARM64_PSTATE_SPSEL = 0x05;;
let _ARM64_PSTATE_DAIFSET = 0x1e;;
let _ARM64_PSTATE_DAIFCLR = 0x1f;;
let _ARM64_PSTATE_PAN = 0x4;;
let _ARM64_PSTATE_UAO = 0x3;;
let _ARM64_PSTATE_DIT = 0x1a;;

let _ARM64_VAS_INVALID = 0;;
let _ARM64_VAS_16B = 1;;
let _ARM64_VAS_8B = 2;;
let _ARM64_VAS_4B = 3;;
let _ARM64_VAS_1B = 4;;
let _ARM64_VAS_8H = 5;;
let _ARM64_VAS_4H = 6;;
let _ARM64_VAS_2H = 7;;
let _ARM64_VAS_1H = 8;;
let _ARM64_VAS_4S = 9;;
let _ARM64_VAS_2S = 10;;
let _ARM64_VAS_1S = 11;;
let _ARM64_VAS_2D = 12;;
let _ARM64_VAS_1D = 13;;
let _ARM64_VAS_1Q = 14;;

let _ARM64_BARRIER_INVALID = 0;;
let _ARM64_BARRIER_OSHLD = 0x1;;
let _ARM64_BARRIER_OSHST = 0x2;;
let _ARM64_BARRIER_OSH = 0x3;;
let _ARM64_BARRIER_NSHLD = 0x5;;
let _ARM64_BARRIER_NSHST = 0x6;;
let _ARM64_BARRIER_NSH = 0x7;;
let _ARM64_BARRIER_ISHLD = 0x9;;
let _ARM64_BARRIER_ISHST = 0xa;;
let _ARM64_BARRIER_ISH = 0xb;;
let _ARM64_BARRIER_LD = 0xd;;
let _ARM64_BARRIER_ST = 0xe;;
let _ARM64_BARRIER_SY = 0xf;;

let _ARM64_OP_INVALID = 0;;
let _ARM64_OP_REG = 1;;
let _ARM64_OP_IMM = 2;;
let _ARM64_OP_MEM = 3;;
let _ARM64_OP_FP = 4;;
let _ARM64_OP_CIMM = 64;;
let _ARM64_OP_REG_MRS = 65;;
let _ARM64_OP_REG_MSR = 66;;
let _ARM64_OP_PSTATE = 67;;
let _ARM64_OP_SYS = 68;;
let _ARM64_OP_SVCR = 69;;
let _ARM64_OP_PREFETCH = 70;;
let _ARM64_OP_BARRIER = 71;;
let _ARM64_OP_SME_INDEX = 72;;

let _ARM64_SYS_INVALID = 0;;
let _ARM64_TLBI_ALLE1 = 1;;
let _ARM64_TLBI_ALLE1IS = 2;;
let _ARM64_TLBI_ALLE1ISNXS = 3;;
let _ARM64_TLBI_ALLE1NXS = 4;;
let _ARM64_TLBI_ALLE1OS = 5;;
let _ARM64_TLBI_ALLE1OSNXS = 6;;
let _ARM64_TLBI_ALLE2 = 7;;
let _ARM64_TLBI_ALLE2IS = 8;;
let _ARM64_TLBI_ALLE2ISNXS = 9;;
let _ARM64_TLBI_ALLE2NXS = 10;;
let _ARM64_TLBI_ALLE2OS = 11;;
let _ARM64_TLBI_ALLE2OSNXS = 12;;
let _ARM64_TLBI_ALLE3 = 13;;
let _ARM64_TLBI_ALLE3IS = 14;;
let _ARM64_TLBI_ALLE3ISNXS = 15;;
let _ARM64_TLBI_ALLE3NXS = 16;;
let _ARM64_TLBI_ALLE3OS = 17;;
let _ARM64_TLBI_ALLE3OSNXS = 18;;
let _ARM64_TLBI_ASIDE1 = 19;;
let _ARM64_TLBI_ASIDE1IS = 20;;
let _ARM64_TLBI_ASIDE1ISNXS = 21;;
let _ARM64_TLBI_ASIDE1NXS = 22;;
let _ARM64_TLBI_ASIDE1OS = 23;;
let _ARM64_TLBI_ASIDE1OSNXS = 24;;
let _ARM64_TLBI_IPAS2E1 = 25;;
let _ARM64_TLBI_IPAS2E1IS = 26;;
let _ARM64_TLBI_IPAS2E1ISNXS = 27;;
let _ARM64_TLBI_IPAS2E1NXS = 28;;
let _ARM64_TLBI_IPAS2E1OS = 29;;
let _ARM64_TLBI_IPAS2E1OSNXS = 30;;
let _ARM64_TLBI_IPAS2LE1 = 31;;
let _ARM64_TLBI_IPAS2LE1IS = 32;;
let _ARM64_TLBI_IPAS2LE1ISNXS = 33;;
let _ARM64_TLBI_IPAS2LE1NXS = 34;;
let _ARM64_TLBI_IPAS2LE1OS = 35;;
let _ARM64_TLBI_IPAS2LE1OSNXS = 36;;
let _ARM64_TLBI_PAALL = 37;;
let _ARM64_TLBI_PAALLNXS = 38;;
let _ARM64_TLBI_PAALLOS = 39;;
let _ARM64_TLBI_PAALLOSNXS = 40;;
let _ARM64_TLBI_RIPAS2E1 = 41;;
let _ARM64_TLBI_RIPAS2E1IS = 42;;
let _ARM64_TLBI_RIPAS2E1ISNXS = 43;;
let _ARM64_TLBI_RIPAS2E1NXS = 44;;
let _ARM64_TLBI_RIPAS2E1OS = 45;;
let _ARM64_TLBI_RIPAS2E1OSNXS = 46;;
let _ARM64_TLBI_RIPAS2LE1 = 47;;
let _ARM64_TLBI_RIPAS2LE1IS = 48;;
let _ARM64_TLBI_RIPAS2LE1ISNXS = 49;;
let _ARM64_TLBI_RIPAS2LE1NXS = 50;;
let _ARM64_TLBI_RIPAS2LE1OS = 51;;
let _ARM64_TLBI_RIPAS2LE1OSNXS = 52;;
let _ARM64_TLBI_RPALOS = 53;;
let _ARM64_TLBI_RPALOSNXS = 54;;
let _ARM64_TLBI_RPAOS = 55;;
let _ARM64_TLBI_RPAOSNXS = 56;;
let _ARM64_TLBI_RVAAE1 = 57;;
let _ARM64_TLBI_RVAAE1IS = 58;;
let _ARM64_TLBI_RVAAE1ISNXS = 59;;
let _ARM64_TLBI_RVAAE1NXS = 60;;
let _ARM64_TLBI_RVAAE1OS = 61;;
let _ARM64_TLBI_RVAAE1OSNXS = 62;;
let _ARM64_TLBI_RVAALE1 = 63;;
let _ARM64_TLBI_RVAALE1IS = 64;;
let _ARM64_TLBI_RVAALE1ISNXS = 65;;
let _ARM64_TLBI_RVAALE1NXS = 66;;
let _ARM64_TLBI_RVAALE1OS = 67;;
let _ARM64_TLBI_RVAALE1OSNXS = 68;;
let _ARM64_TLBI_RVAE1 = 69;;
let _ARM64_TLBI_RVAE1IS = 70;;
let _ARM64_TLBI_RVAE1ISNXS = 71;;
let _ARM64_TLBI_RVAE1NXS = 72;;
let _ARM64_TLBI_RVAE1OS = 73;;
let _ARM64_TLBI_RVAE1OSNXS = 74;;
let _ARM64_TLBI_RVAE2 = 75;;
let _ARM64_TLBI_RVAE2IS = 76;;
let _ARM64_TLBI_RVAE2ISNXS = 77;;
let _ARM64_TLBI_RVAE2NXS = 78;;
let _ARM64_TLBI_RVAE2OS = 79;;
let _ARM64_TLBI_RVAE2OSNXS = 80;;
let _ARM64_TLBI_RVAE3 = 81;;
let _ARM64_TLBI_RVAE3IS = 82;;
let _ARM64_TLBI_RVAE3ISNXS = 83;;
let _ARM64_TLBI_RVAE3NXS = 84;;
let _ARM64_TLBI_RVAE3OS = 85;;
let _ARM64_TLBI_RVAE3OSNXS = 86;;
let _ARM64_TLBI_RVALE1 = 87;;
let _ARM64_TLBI_RVALE1IS = 88;;
let _ARM64_TLBI_RVALE1ISNXS = 89;;
let _ARM64_TLBI_RVALE1NXS = 90;;
let _ARM64_TLBI_RVALE1OS = 91;;
let _ARM64_TLBI_RVALE1OSNXS = 92;;
let _ARM64_TLBI_RVALE2 = 93;;
let _ARM64_TLBI_RVALE2IS = 94;;
let _ARM64_TLBI_RVALE2ISNXS = 95;;
let _ARM64_TLBI_RVALE2NXS = 96;;
let _ARM64_TLBI_RVALE2OS = 97;;
let _ARM64_TLBI_RVALE2OSNXS = 98;;
let _ARM64_TLBI_RVALE3 = 99;;
let _ARM64_TLBI_RVALE3IS = 100;;
let _ARM64_TLBI_RVALE3ISNXS = 101;;
let _ARM64_TLBI_RVALE3NXS = 102;;
let _ARM64_TLBI_RVALE3OS = 103;;
let _ARM64_TLBI_RVALE3OSNXS = 104;;
let _ARM64_TLBI_VAAE1 = 105;;
let _ARM64_TLBI_VAAE1IS = 106;;
let _ARM64_TLBI_VAAE1ISNXS = 107;;
let _ARM64_TLBI_VAAE1NXS = 108;;
let _ARM64_TLBI_VAAE1OS = 109;;
let _ARM64_TLBI_VAAE1OSNXS = 110;;
let _ARM64_TLBI_VAALE1 = 111;;
let _ARM64_TLBI_VAALE1IS = 112;;
let _ARM64_TLBI_VAALE1ISNXS = 113;;
let _ARM64_TLBI_VAALE1NXS = 114;;
let _ARM64_TLBI_VAALE1OS = 115;;
let _ARM64_TLBI_VAALE1OSNXS = 116;;
let _ARM64_TLBI_VAE1 = 117;;
let _ARM64_TLBI_VAE1IS = 118;;
let _ARM64_TLBI_VAE1ISNXS = 119;;
let _ARM64_TLBI_VAE1NXS = 120;;
let _ARM64_TLBI_VAE1OS = 121;;
let _ARM64_TLBI_VAE1OSNXS = 122;;
let _ARM64_TLBI_VAE2 = 123;;
let _ARM64_TLBI_VAE2IS = 124;;
let _ARM64_TLBI_VAE2ISNXS = 125;;
let _ARM64_TLBI_VAE2NXS = 126;;
let _ARM64_TLBI_VAE2OS = 127;;
let _ARM64_TLBI_VAE2OSNXS = 128;;
let _ARM64_TLBI_VAE3 = 129;;
let _ARM64_TLBI_VAE3IS = 130;;
let _ARM64_TLBI_VAE3ISNXS = 131;;
let _ARM64_TLBI_VAE3NXS = 132;;
let _ARM64_TLBI_VAE3OS = 133;;
let _ARM64_TLBI_VAE3OSNXS = 134;;
let _ARM64_TLBI_VALE1 = 135;;
let _ARM64_TLBI_VALE1IS = 136;;
let _ARM64_TLBI_VALE1ISNXS = 137;;
let _ARM64_TLBI_VALE1NXS = 138;;
let _ARM64_TLBI_VALE1OS = 139;;
let _ARM64_TLBI_VALE1OSNXS = 140;;
let _ARM64_TLBI_VALE2 = 141;;
let _ARM64_TLBI_VALE2IS = 142;;
let _ARM64_TLBI_VALE2ISNXS = 143;;
let _ARM64_TLBI_VALE2NXS = 144;;
let _ARM64_TLBI_VALE2OS = 145;;
let _ARM64_TLBI_VALE2OSNXS = 146;;
let _ARM64_TLBI_VALE3 = 147;;
let _ARM64_TLBI_VALE3IS = 148;;
let _ARM64_TLBI_VALE3ISNXS = 149;;
let _ARM64_TLBI_VALE3NXS = 150;;
let _ARM64_TLBI_VALE3OS = 151;;
let _ARM64_TLBI_VALE3OSNXS = 152;;
let _ARM64_TLBI_VMALLE1 = 153;;
let _ARM64_TLBI_VMALLE1IS = 154;;
let _ARM64_TLBI_VMALLE1ISNXS = 155;;
let _ARM64_TLBI_VMALLE1NXS = 156;;
let _ARM64_TLBI_VMALLE1OS = 157;;
let _ARM64_TLBI_VMALLE1OSNXS = 158;;
let _ARM64_TLBI_VMALLS12E1 = 159;;
let _ARM64_TLBI_VMALLS12E1IS = 160;;
let _ARM64_TLBI_VMALLS12E1ISNXS = 161;;
let _ARM64_TLBI_VMALLS12E1NXS = 162;;
let _ARM64_TLBI_VMALLS12E1OS = 163;;
let _ARM64_TLBI_VMALLS12E1OSNXS = 164;;
let _ARM64_AT_S1E1R = 165;;
let _ARM64_AT_S1E2R = 166;;
let _ARM64_AT_S1E3R = 167;;
let _ARM64_AT_S1E1W = 168;;
let _ARM64_AT_S1E2W = 169;;
let _ARM64_AT_S1E3W = 170;;
let _ARM64_AT_S1E0R = 171;;
let _ARM64_AT_S1E0W = 172;;
let _ARM64_AT_S12E1R = 173;;
let _ARM64_AT_S12E1W = 174;;
let _ARM64_AT_S12E0R = 175;;
let _ARM64_AT_S12E0W = 176;;
let _ARM64_AT_S1E1RP = 177;;
let _ARM64_AT_S1E1WP = 178;;
let _ARM64_DC_CGDSW = 179;;
let _ARM64_DC_CGDVAC = 180;;
let _ARM64_DC_CGDVADP = 181;;
let _ARM64_DC_CGDVAP = 182;;
let _ARM64_DC_CGSW = 183;;
let _ARM64_DC_CGVAC = 184;;
let _ARM64_DC_CGVADP = 185;;
let _ARM64_DC_CGVAP = 186;;
let _ARM64_DC_CIGDSW = 187;;
let _ARM64_DC_CIGDVAC = 188;;
let _ARM64_DC_CIGSW = 189;;
let _ARM64_DC_CIGVAC = 190;;
let _ARM64_DC_CISW = 191;;
let _ARM64_DC_CIVAC = 192;;
let _ARM64_DC_CSW = 193;;
let _ARM64_DC_CVAC = 194;;
let _ARM64_DC_CVADP = 195;;
let _ARM64_DC_CVAP = 196;;
let _ARM64_DC_CVAU = 197;;
let _ARM64_DC_GVA = 198;;
let _ARM64_DC_GZVA = 199;;
let _ARM64_DC_IGDSW = 200;;
let _ARM64_DC_IGDVAC = 201;;
let _ARM64_DC_IGSW = 202;;
let _ARM64_DC_IGVAC = 203;;
let _ARM64_DC_ISW = 204;;
let _ARM64_DC_IVAC = 205;;
let _ARM64_DC_ZVA = 206;;
let _ARM64_IC_IALLUIS = 207;;
let _ARM64_IC_IALLU = 208;;
let _ARM64_IC_IVAU = 209;;

let _ARM64_SVCR_INVALID = 0;;
let _ARM64_SVCR_SVCRSM = 0x1;;
let _ARM64_SVCR_SVCRSMZA = 0x3;;
let _ARM64_SVCR_SVCRZA = 0x2;;

let _ARM64_PRFM_INVALID = 0;;
let _ARM64_PRFM_PLDL1KEEP = 0x00+1;;
let _ARM64_PRFM_PLDL1STRM = 0x01+1;;
let _ARM64_PRFM_PLDL2KEEP = 0x02+1;;
let _ARM64_PRFM_PLDL2STRM = 0x03+1;;
let _ARM64_PRFM_PLDL3KEEP = 0x04+1;;
let _ARM64_PRFM_PLDL3STRM = 0x05+1;;
let _ARM64_PRFM_PLIL1KEEP = 0x08+1;;
let _ARM64_PRFM_PLIL1STRM = 0x09+1;;
let _ARM64_PRFM_PLIL2KEEP = 0x0a+1;;
let _ARM64_PRFM_PLIL2STRM = 0x0b+1;;
let _ARM64_PRFM_PLIL3KEEP = 0x0c+1;;
let _ARM64_PRFM_PLIL3STRM = 0x0d+1;;
let _ARM64_PRFM_PSTL1KEEP = 0x10+1;;
let _ARM64_PRFM_PSTL1STRM = 0x11+1;;
let _ARM64_PRFM_PSTL2KEEP = 0x12+1;;
let _ARM64_PRFM_PSTL2STRM = 0x13+1;;
let _ARM64_PRFM_PSTL3KEEP = 0x14+1;;
let _ARM64_PRFM_PSTL3STRM = 0x15+1;;

let _ARM64_REG_INVALID = 0;;
let _ARM64_REG_FFR = 1;;
let _ARM64_REG_FP = 2;;
let _ARM64_REG_LR = 3;;
let _ARM64_REG_NZCV = 4;;
let _ARM64_REG_SP = 5;;
let _ARM64_REG_VG = 6;;
let _ARM64_REG_WSP = 7;;
let _ARM64_REG_WZR = 8;;
let _ARM64_REG_XZR = 9;;
let _ARM64_REG_ZA = 10;;
let _ARM64_REG_B0 = 11;;
let _ARM64_REG_B1 = 12;;
let _ARM64_REG_B2 = 13;;
let _ARM64_REG_B3 = 14;;
let _ARM64_REG_B4 = 15;;
let _ARM64_REG_B5 = 16;;
let _ARM64_REG_B6 = 17;;
let _ARM64_REG_B7 = 18;;
let _ARM64_REG_B8 = 19;;
let _ARM64_REG_B9 = 20;;
let _ARM64_REG_B10 = 21;;
let _ARM64_REG_B11 = 22;;
let _ARM64_REG_B12 = 23;;
let _ARM64_REG_B13 = 24;;
let _ARM64_REG_B14 = 25;;
let _ARM64_REG_B15 = 26;;
let _ARM64_REG_B16 = 27;;
let _ARM64_REG_B17 = 28;;
let _ARM64_REG_B18 = 29;;
let _ARM64_REG_B19 = 30;;
let _ARM64_REG_B20 = 31;;
let _ARM64_REG_B21 = 32;;
let _ARM64_REG_B22 = 33;;
let _ARM64_REG_B23 = 34;;
let _ARM64_REG_B24 = 35;;
let _ARM64_REG_B25 = 36;;
let _ARM64_REG_B26 = 37;;
let _ARM64_REG_B27 = 38;;
let _ARM64_REG_B28 = 39;;
let _ARM64_REG_B29 = 40;;
let _ARM64_REG_B30 = 41;;
let _ARM64_REG_B31 = 42;;
let _ARM64_REG_D0 = 43;;
let _ARM64_REG_D1 = 44;;
let _ARM64_REG_D2 = 45;;
let _ARM64_REG_D3 = 46;;
let _ARM64_REG_D4 = 47;;
let _ARM64_REG_D5 = 48;;
let _ARM64_REG_D6 = 49;;
let _ARM64_REG_D7 = 50;;
let _ARM64_REG_D8 = 51;;
let _ARM64_REG_D9 = 52;;
let _ARM64_REG_D10 = 53;;
let _ARM64_REG_D11 = 54;;
let _ARM64_REG_D12 = 55;;
let _ARM64_REG_D13 = 56;;
let _ARM64_REG_D14 = 57;;
let _ARM64_REG_D15 = 58;;
let _ARM64_REG_D16 = 59;;
let _ARM64_REG_D17 = 60;;
let _ARM64_REG_D18 = 61;;
let _ARM64_REG_D19 = 62;;
let _ARM64_REG_D20 = 63;;
let _ARM64_REG_D21 = 64;;
let _ARM64_REG_D22 = 65;;
let _ARM64_REG_D23 = 66;;
let _ARM64_REG_D24 = 67;;
let _ARM64_REG_D25 = 68;;
let _ARM64_REG_D26 = 69;;
let _ARM64_REG_D27 = 70;;
let _ARM64_REG_D28 = 71;;
let _ARM64_REG_D29 = 72;;
let _ARM64_REG_D30 = 73;;
let _ARM64_REG_D31 = 74;;
let _ARM64_REG_H0 = 75;;
let _ARM64_REG_H1 = 76;;
let _ARM64_REG_H2 = 77;;
let _ARM64_REG_H3 = 78;;
let _ARM64_REG_H4 = 79;;
let _ARM64_REG_H5 = 80;;
let _ARM64_REG_H6 = 81;;
let _ARM64_REG_H7 = 82;;
let _ARM64_REG_H8 = 83;;
let _ARM64_REG_H9 = 84;;
let _ARM64_REG_H10 = 85;;
let _ARM64_REG_H11 = 86;;
let _ARM64_REG_H12 = 87;;
let _ARM64_REG_H13 = 88;;
let _ARM64_REG_H14 = 89;;
let _ARM64_REG_H15 = 90;;
let _ARM64_REG_H16 = 91;;
let _ARM64_REG_H17 = 92;;
let _ARM64_REG_H18 = 93;;
let _ARM64_REG_H19 = 94;;
let _ARM64_REG_H20 = 95;;
let _ARM64_REG_H21 = 96;;
let _ARM64_REG_H22 = 97;;
let _ARM64_REG_H23 = 98;;
let _ARM64_REG_H24 = 99;;
let _ARM64_REG_H25 = 100;;
let _ARM64_REG_H26 = 101;;
let _ARM64_REG_H27 = 102;;
let _ARM64_REG_H28 = 103;;
let _ARM64_REG_H29 = 104;;
let _ARM64_REG_H30 = 105;;
let _ARM64_REG_H31 = 106;;
let _ARM64_REG_P0 = 107;;
let _ARM64_REG_P1 = 108;;
let _ARM64_REG_P2 = 109;;
let _ARM64_REG_P3 = 110;;
let _ARM64_REG_P4 = 111;;
let _ARM64_REG_P5 = 112;;
let _ARM64_REG_P6 = 113;;
let _ARM64_REG_P7 = 114;;
let _ARM64_REG_P8 = 115;;
let _ARM64_REG_P9 = 116;;
let _ARM64_REG_P10 = 117;;
let _ARM64_REG_P11 = 118;;
let _ARM64_REG_P12 = 119;;
let _ARM64_REG_P13 = 120;;
let _ARM64_REG_P14 = 121;;
let _ARM64_REG_P15 = 122;;
let _ARM64_REG_Q0 = 123;;
let _ARM64_REG_Q1 = 124;;
let _ARM64_REG_Q2 = 125;;
let _ARM64_REG_Q3 = 126;;
let _ARM64_REG_Q4 = 127;;
let _ARM64_REG_Q5 = 128;;
let _ARM64_REG_Q6 = 129;;
let _ARM64_REG_Q7 = 130;;
let _ARM64_REG_Q8 = 131;;
let _ARM64_REG_Q9 = 132;;
let _ARM64_REG_Q10 = 133;;
let _ARM64_REG_Q11 = 134;;
let _ARM64_REG_Q12 = 135;;
let _ARM64_REG_Q13 = 136;;
let _ARM64_REG_Q14 = 137;;
let _ARM64_REG_Q15 = 138;;
let _ARM64_REG_Q16 = 139;;
let _ARM64_REG_Q17 = 140;;
let _ARM64_REG_Q18 = 141;;
let _ARM64_REG_Q19 = 142;;
let _ARM64_REG_Q20 = 143;;
let _ARM64_REG_Q21 = 144;;
let _ARM64_REG_Q22 = 145;;
let _ARM64_REG_Q23 = 146;;
let _ARM64_REG_Q24 = 147;;
let _ARM64_REG_Q25 = 148;;
let _ARM64_REG_Q26 = 149;;
let _ARM64_REG_Q27 = 150;;
let _ARM64_REG_Q28 = 151;;
let _ARM64_REG_Q29 = 152;;
let _ARM64_REG_Q30 = 153;;
let _ARM64_REG_Q31 = 154;;
let _ARM64_REG_S0 = 155;;
let _ARM64_REG_S1 = 156;;
let _ARM64_REG_S2 = 157;;
let _ARM64_REG_S3 = 158;;
let _ARM64_REG_S4 = 159;;
let _ARM64_REG_S5 = 160;;
let _ARM64_REG_S6 = 161;;
let _ARM64_REG_S7 = 162;;
let _ARM64_REG_S8 = 163;;
let _ARM64_REG_S9 = 164;;
let _ARM64_REG_S10 = 165;;
let _ARM64_REG_S11 = 166;;
let _ARM64_REG_S12 = 167;;
let _ARM64_REG_S13 = 168;;
let _ARM64_REG_S14 = 169;;
let _ARM64_REG_S15 = 170;;
let _ARM64_REG_S16 = 171;;
let _ARM64_REG_S17 = 172;;
let _ARM64_REG_S18 = 173;;
let _ARM64_REG_S19 = 174;;
let _ARM64_REG_S20 = 175;;
let _ARM64_REG_S21 = 176;;
let _ARM64_REG_S22 = 177;;
let _ARM64_REG_S23 = 178;;
let _ARM64_REG_S24 = 179;;
let _ARM64_REG_S25 = 180;;
let _ARM64_REG_S26 = 181;;
let _ARM64_REG_S27 = 182;;
let _ARM64_REG_S28 = 183;;
let _ARM64_REG_S29 = 184;;
let _ARM64_REG_S30 = 185;;
let _ARM64_REG_S31 = 186;;
let _ARM64_REG_W0 = 187;;
let _ARM64_REG_W1 = 188;;
let _ARM64_REG_W2 = 189;;
let _ARM64_REG_W3 = 190;;
let _ARM64_REG_W4 = 191;;
let _ARM64_REG_W5 = 192;;
let _ARM64_REG_W6 = 193;;
let _ARM64_REG_W7 = 194;;
let _ARM64_REG_W8 = 195;;
let _ARM64_REG_W9 = 196;;
let _ARM64_REG_W10 = 197;;
let _ARM64_REG_W11 = 198;;
let _ARM64_REG_W12 = 199;;
let _ARM64_REG_W13 = 200;;
let _ARM64_REG_W14 = 201;;
let _ARM64_REG_W15 = 202;;
let _ARM64_REG_W16 = 203;;
let _ARM64_REG_W17 = 204;;
let _ARM64_REG_W18 = 205;;
let _ARM64_REG_W19 = 206;;
let _ARM64_REG_W20 = 207;;
let _ARM64_REG_W21 = 208;;
let _ARM64_REG_W22 = 209;;
let _ARM64_REG_W23 = 210;;
let _ARM64_REG_W24 = 211;;
let _ARM64_REG_W25 = 212;;
let _ARM64_REG_W26 = 213;;
let _ARM64_REG_W27 = 214;;
let _ARM64_REG_W28 = 215;;
let _ARM64_REG_W29 = 216;;
let _ARM64_REG_W30 = 217;;
let _ARM64_REG_X0 = 218;;
let _ARM64_REG_X1 = 219;;
let _ARM64_REG_X2 = 220;;
let _ARM64_REG_X3 = 221;;
let _ARM64_REG_X4 = 222;;
let _ARM64_REG_X5 = 223;;
let _ARM64_REG_X6 = 224;;
let _ARM64_REG_X7 = 225;;
let _ARM64_REG_X8 = 226;;
let _ARM64_REG_X9 = 227;;
let _ARM64_REG_X10 = 228;;
let _ARM64_REG_X11 = 229;;
let _ARM64_REG_X12 = 230;;
let _ARM64_REG_X13 = 231;;
let _ARM64_REG_X14 = 232;;
let _ARM64_REG_X15 = 233;;
let _ARM64_REG_X16 = 234;;
let _ARM64_REG_X17 = 235;;
let _ARM64_REG_X18 = 236;;
let _ARM64_REG_X19 = 237;;
let _ARM64_REG_X20 = 238;;
let _ARM64_REG_X21 = 239;;
let _ARM64_REG_X22 = 240;;
let _ARM64_REG_X23 = 241;;
let _ARM64_REG_X24 = 242;;
let _ARM64_REG_X25 = 243;;
let _ARM64_REG_X26 = 244;;
let _ARM64_REG_X27 = 245;;
let _ARM64_REG_X28 = 246;;
let _ARM64_REG_Z0 = 247;;
let _ARM64_REG_Z1 = 248;;
let _ARM64_REG_Z2 = 249;;
let _ARM64_REG_Z3 = 250;;
let _ARM64_REG_Z4 = 251;;
let _ARM64_REG_Z5 = 252;;
let _ARM64_REG_Z6 = 253;;
let _ARM64_REG_Z7 = 254;;
let _ARM64_REG_Z8 = 255;;
let _ARM64_REG_Z9 = 256;;
let _ARM64_REG_Z10 = 257;;
let _ARM64_REG_Z11 = 258;;
let _ARM64_REG_Z12 = 259;;
let _ARM64_REG_Z13 = 260;;
let _ARM64_REG_Z14 = 261;;
let _ARM64_REG_Z15 = 262;;
let _ARM64_REG_Z16 = 263;;
let _ARM64_REG_Z17 = 264;;
let _ARM64_REG_Z18 = 265;;
let _ARM64_REG_Z19 = 266;;
let _ARM64_REG_Z20 = 267;;
let _ARM64_REG_Z21 = 268;;
let _ARM64_REG_Z22 = 269;;
let _ARM64_REG_Z23 = 270;;
let _ARM64_REG_Z24 = 271;;
let _ARM64_REG_Z25 = 272;;
let _ARM64_REG_Z26 = 273;;
let _ARM64_REG_Z27 = 274;;
let _ARM64_REG_Z28 = 275;;
let _ARM64_REG_Z29 = 276;;
let _ARM64_REG_Z30 = 277;;
let _ARM64_REG_Z31 = 278;;
let _ARM64_REG_ZAB0 = 279;;
let _ARM64_REG_ZAD0 = 280;;
let _ARM64_REG_ZAD1 = 281;;
let _ARM64_REG_ZAD2 = 282;;
let _ARM64_REG_ZAD3 = 283;;
let _ARM64_REG_ZAD4 = 284;;
let _ARM64_REG_ZAD5 = 285;;
let _ARM64_REG_ZAD6 = 286;;
let _ARM64_REG_ZAD7 = 287;;
let _ARM64_REG_ZAH0 = 288;;
let _ARM64_REG_ZAH1 = 289;;
let _ARM64_REG_ZAQ0 = 290;;
let _ARM64_REG_ZAQ1 = 291;;
let _ARM64_REG_ZAQ2 = 292;;
let _ARM64_REG_ZAQ3 = 293;;
let _ARM64_REG_ZAQ4 = 294;;
let _ARM64_REG_ZAQ5 = 295;;
let _ARM64_REG_ZAQ6 = 296;;
let _ARM64_REG_ZAQ7 = 297;;
let _ARM64_REG_ZAQ8 = 298;;
let _ARM64_REG_ZAQ9 = 299;;
let _ARM64_REG_ZAQ10 = 300;;
let _ARM64_REG_ZAQ11 = 301;;
let _ARM64_REG_ZAQ12 = 302;;
let _ARM64_REG_ZAQ13 = 303;;
let _ARM64_REG_ZAQ14 = 304;;
let _ARM64_REG_ZAQ15 = 305;;
let _ARM64_REG_ZAS0 = 306;;
let _ARM64_REG_ZAS1 = 307;;
let _ARM64_REG_ZAS2 = 308;;
let _ARM64_REG_ZAS3 = 309;;
let _ARM64_REG_V0 = 310;;
let _ARM64_REG_V1 = 311;;
let _ARM64_REG_V2 = 312;;
let _ARM64_REG_V3 = 313;;
let _ARM64_REG_V4 = 314;;
let _ARM64_REG_V5 = 315;;
let _ARM64_REG_V6 = 316;;
let _ARM64_REG_V7 = 317;;
let _ARM64_REG_V8 = 318;;
let _ARM64_REG_V9 = 319;;
let _ARM64_REG_V10 = 320;;
let _ARM64_REG_V11 = 321;;
let _ARM64_REG_V12 = 322;;
let _ARM64_REG_V13 = 323;;
let _ARM64_REG_V14 = 324;;
let _ARM64_REG_V15 = 325;;
let _ARM64_REG_V16 = 326;;
let _ARM64_REG_V17 = 327;;
let _ARM64_REG_V18 = 328;;
let _ARM64_REG_V19 = 329;;
let _ARM64_REG_V20 = 330;;
let _ARM64_REG_V21 = 331;;
let _ARM64_REG_V22 = 332;;
let _ARM64_REG_V23 = 333;;
let _ARM64_REG_V24 = 334;;
let _ARM64_REG_V25 = 335;;
let _ARM64_REG_V26 = 336;;
let _ARM64_REG_V27 = 337;;
let _ARM64_REG_V28 = 338;;
let _ARM64_REG_V29 = 339;;
let _ARM64_REG_V30 = 340;;
let _ARM64_REG_V31 = 341;;
let _ARM64_REG_ENDING = 342;;
let _ARM64_REG_IP0 = _ARM64_REG_X16;;
let _ARM64_REG_IP1 = _ARM64_REG_X17;;
let _ARM64_REG_X29 = _ARM64_REG_FP;;
let _ARM64_REG_X30 = _ARM64_REG_LR;;

let _ARM64_INS_INVALID = 0;;
let _ARM64_INS_ABS = 1;;
let _ARM64_INS_ADC = 2;;
let _ARM64_INS_ADCLB = 3;;
let _ARM64_INS_ADCLT = 4;;
let _ARM64_INS_ADCS = 5;;
let _ARM64_INS_ADD = 6;;
let _ARM64_INS_ADDG = 7;;
let _ARM64_INS_ADDHA = 8;;
let _ARM64_INS_ADDHN = 9;;
let _ARM64_INS_ADDHN2 = 10;;
let _ARM64_INS_ADDHNB = 11;;
let _ARM64_INS_ADDHNT = 12;;
let _ARM64_INS_ADDP = 13;;
let _ARM64_INS_ADDPL = 14;;
let _ARM64_INS_ADDS = 15;;
let _ARM64_INS_ADDV = 16;;
let _ARM64_INS_ADDVA = 17;;
let _ARM64_INS_ADDVL = 18;;
let _ARM64_INS_ADR = 19;;
let _ARM64_INS_ADRP = 20;;
let _ARM64_INS_AESD = 21;;
let _ARM64_INS_AESE = 22;;
let _ARM64_INS_AESIMC = 23;;
let _ARM64_INS_AESMC = 24;;
let _ARM64_INS_AND = 25;;
let _ARM64_INS_ANDS = 26;;
let _ARM64_INS_ANDV = 27;;
let _ARM64_INS_ASR = 28;;
let _ARM64_INS_ASRD = 29;;
let _ARM64_INS_ASRR = 30;;
let _ARM64_INS_ASRV = 31;;
let _ARM64_INS_AUTDA = 32;;
let _ARM64_INS_AUTDB = 33;;
let _ARM64_INS_AUTDZA = 34;;
let _ARM64_INS_AUTDZB = 35;;
let _ARM64_INS_AUTIA = 36;;
let _ARM64_INS_AUTIA1716 = 37;;
let _ARM64_INS_AUTIASP = 38;;
let _ARM64_INS_AUTIAZ = 39;;
let _ARM64_INS_AUTIB = 40;;
let _ARM64_INS_AUTIB1716 = 41;;
let _ARM64_INS_AUTIBSP = 42;;
let _ARM64_INS_AUTIBZ = 43;;
let _ARM64_INS_AUTIZA = 44;;
let _ARM64_INS_AUTIZB = 45;;
let _ARM64_INS_AXFLAG = 46;;
let _ARM64_INS_B = 47;;
let _ARM64_INS_BC = 48;;
let _ARM64_INS_BCAX = 49;;
let _ARM64_INS_BDEP = 50;;
let _ARM64_INS_BEXT = 51;;
let _ARM64_INS_BFCVT = 52;;
let _ARM64_INS_BFCVTN = 53;;
let _ARM64_INS_BFCVTN2 = 54;;
let _ARM64_INS_BFCVTNT = 55;;
let _ARM64_INS_BFDOT = 56;;
let _ARM64_INS_BFM = 57;;
let _ARM64_INS_BFMLALB = 58;;
let _ARM64_INS_BFMLALT = 59;;
let _ARM64_INS_BFMMLA = 60;;
let _ARM64_INS_BFMOPA = 61;;
let _ARM64_INS_BFMOPS = 62;;
let _ARM64_INS_BGRP = 63;;
let _ARM64_INS_BIC = 64;;
let _ARM64_INS_BICS = 65;;
let _ARM64_INS_BIF = 66;;
let _ARM64_INS_BIT = 67;;
let _ARM64_INS_BL = 68;;
let _ARM64_INS_BLR = 69;;
let _ARM64_INS_BLRAA = 70;;
let _ARM64_INS_BLRAAZ = 71;;
let _ARM64_INS_BLRAB = 72;;
let _ARM64_INS_BLRABZ = 73;;
let _ARM64_INS_BR = 74;;
let _ARM64_INS_BRAA = 75;;
let _ARM64_INS_BRAAZ = 76;;
let _ARM64_INS_BRAB = 77;;
let _ARM64_INS_BRABZ = 78;;
let _ARM64_INS_BRB = 79;;
let _ARM64_INS_BRK = 80;;
let _ARM64_INS_BRKA = 81;;
let _ARM64_INS_BRKAS = 82;;
let _ARM64_INS_BRKB = 83;;
let _ARM64_INS_BRKBS = 84;;
let _ARM64_INS_BRKN = 85;;
let _ARM64_INS_BRKNS = 86;;
let _ARM64_INS_BRKPA = 87;;
let _ARM64_INS_BRKPAS = 88;;
let _ARM64_INS_BRKPB = 89;;
let _ARM64_INS_BRKPBS = 90;;
let _ARM64_INS_BSL = 91;;
let _ARM64_INS_BSL1N = 92;;
let _ARM64_INS_BSL2N = 93;;
let _ARM64_INS_BTI = 94;;
let _ARM64_INS_CADD = 95;;
let _ARM64_INS_CAS = 96;;
let _ARM64_INS_CASA = 97;;
let _ARM64_INS_CASAB = 98;;
let _ARM64_INS_CASAH = 99;;
let _ARM64_INS_CASAL = 100;;
let _ARM64_INS_CASALB = 101;;
let _ARM64_INS_CASALH = 102;;
let _ARM64_INS_CASB = 103;;
let _ARM64_INS_CASH = 104;;
let _ARM64_INS_CASL = 105;;
let _ARM64_INS_CASLB = 106;;
let _ARM64_INS_CASLH = 107;;
let _ARM64_INS_CASP = 108;;
let _ARM64_INS_CASPA = 109;;
let _ARM64_INS_CASPAL = 110;;
let _ARM64_INS_CASPL = 111;;
let _ARM64_INS_CBNZ = 112;;
let _ARM64_INS_CBZ = 113;;
let _ARM64_INS_CCMN = 114;;
let _ARM64_INS_CCMP = 115;;
let _ARM64_INS_CDOT = 116;;
let _ARM64_INS_CFINV = 117;;
let _ARM64_INS_CINC = 118;;
let _ARM64_INS_CINV = 119;;
let _ARM64_INS_CLASTA = 120;;
let _ARM64_INS_CLASTB = 121;;
let _ARM64_INS_CLREX = 122;;
let _ARM64_INS_CLS = 123;;
let _ARM64_INS_CLZ = 124;;
let _ARM64_INS_CMEQ = 125;;
let _ARM64_INS_CMGE = 126;;
let _ARM64_INS_CMGT = 127;;
let _ARM64_INS_CMHI = 128;;
let _ARM64_INS_CMHS = 129;;
let _ARM64_INS_CMLA = 130;;
let _ARM64_INS_CMLE = 131;;
let _ARM64_INS_CMLO = 132;;
let _ARM64_INS_CMLS = 133;;
let _ARM64_INS_CMLT = 134;;
let _ARM64_INS_CMN = 135;;
let _ARM64_INS_CMP = 136;;
let _ARM64_INS_CMPEQ = 137;;
let _ARM64_INS_CMPGE = 138;;
let _ARM64_INS_CMPGT = 139;;
let _ARM64_INS_CMPHI = 140;;
let _ARM64_INS_CMPHS = 141;;
let _ARM64_INS_CMPLE = 142;;
let _ARM64_INS_CMPLO = 143;;
let _ARM64_INS_CMPLS = 144;;
let _ARM64_INS_CMPLT = 145;;
let _ARM64_INS_CMPNE = 146;;
let _ARM64_INS_CMPP = 147;;
let _ARM64_INS_CMTST = 148;;
let _ARM64_INS_CNEG = 149;;
let _ARM64_INS_CNOT = 150;;
let _ARM64_INS_CNT = 151;;
let _ARM64_INS_CNTB = 152;;
let _ARM64_INS_CNTD = 153;;
let _ARM64_INS_CNTH = 154;;
let _ARM64_INS_CNTP = 155;;
let _ARM64_INS_CNTW = 156;;
let _ARM64_INS_COMPACT = 157;;
let _ARM64_INS_CPY = 158;;
let _ARM64_INS_CPYE = 159;;
let _ARM64_INS_CPYEN = 160;;
let _ARM64_INS_CPYERN = 161;;
let _ARM64_INS_CPYERT = 162;;
let _ARM64_INS_CPYERTN = 163;;
let _ARM64_INS_CPYERTRN = 164;;
let _ARM64_INS_CPYERTWN = 165;;
let _ARM64_INS_CPYET = 166;;
let _ARM64_INS_CPYETN = 167;;
let _ARM64_INS_CPYETRN = 168;;
let _ARM64_INS_CPYETWN = 169;;
let _ARM64_INS_CPYEWN = 170;;
let _ARM64_INS_CPYEWT = 171;;
let _ARM64_INS_CPYEWTN = 172;;
let _ARM64_INS_CPYEWTRN = 173;;
let _ARM64_INS_CPYEWTWN = 174;;
let _ARM64_INS_CPYFE = 175;;
let _ARM64_INS_CPYFEN = 176;;
let _ARM64_INS_CPYFERN = 177;;
let _ARM64_INS_CPYFERT = 178;;
let _ARM64_INS_CPYFERTN = 179;;
let _ARM64_INS_CPYFERTRN = 180;;
let _ARM64_INS_CPYFERTWN = 181;;
let _ARM64_INS_CPYFET = 182;;
let _ARM64_INS_CPYFETN = 183;;
let _ARM64_INS_CPYFETRN = 184;;
let _ARM64_INS_CPYFETWN = 185;;
let _ARM64_INS_CPYFEWN = 186;;
let _ARM64_INS_CPYFEWT = 187;;
let _ARM64_INS_CPYFEWTN = 188;;
let _ARM64_INS_CPYFEWTRN = 189;;
let _ARM64_INS_CPYFEWTWN = 190;;
let _ARM64_INS_CPYFM = 191;;
let _ARM64_INS_CPYFMN = 192;;
let _ARM64_INS_CPYFMRN = 193;;
let _ARM64_INS_CPYFMRT = 194;;
let _ARM64_INS_CPYFMRTN = 195;;
let _ARM64_INS_CPYFMRTRN = 196;;
let _ARM64_INS_CPYFMRTWN = 197;;
let _ARM64_INS_CPYFMT = 198;;
let _ARM64_INS_CPYFMTN = 199;;
let _ARM64_INS_CPYFMTRN = 200;;
let _ARM64_INS_CPYFMTWN = 201;;
let _ARM64_INS_CPYFMWN = 202;;
let _ARM64_INS_CPYFMWT = 203;;
let _ARM64_INS_CPYFMWTN = 204;;
let _ARM64_INS_CPYFMWTRN = 205;;
let _ARM64_INS_CPYFMWTWN = 206;;
let _ARM64_INS_CPYFP = 207;;
let _ARM64_INS_CPYFPN = 208;;
let _ARM64_INS_CPYFPRN = 209;;
let _ARM64_INS_CPYFPRT = 210;;
let _ARM64_INS_CPYFPRTN = 211;;
let _ARM64_INS_CPYFPRTRN = 212;;
let _ARM64_INS_CPYFPRTWN = 213;;
let _ARM64_INS_CPYFPT = 214;;
let _ARM64_INS_CPYFPTN = 215;;
let _ARM64_INS_CPYFPTRN = 216;;
let _ARM64_INS_CPYFPTWN = 217;;
let _ARM64_INS_CPYFPWN = 218;;
let _ARM64_INS_CPYFPWT = 219;;
let _ARM64_INS_CPYFPWTN = 220;;
let _ARM64_INS_CPYFPWTRN = 221;;
let _ARM64_INS_CPYFPWTWN = 222;;
let _ARM64_INS_CPYM = 223;;
let _ARM64_INS_CPYMN = 224;;
let _ARM64_INS_CPYMRN = 225;;
let _ARM64_INS_CPYMRT = 226;;
let _ARM64_INS_CPYMRTN = 227;;
let _ARM64_INS_CPYMRTRN = 228;;
let _ARM64_INS_CPYMRTWN = 229;;
let _ARM64_INS_CPYMT = 230;;
let _ARM64_INS_CPYMTN = 231;;
let _ARM64_INS_CPYMTRN = 232;;
let _ARM64_INS_CPYMTWN = 233;;
let _ARM64_INS_CPYMWN = 234;;
let _ARM64_INS_CPYMWT = 235;;
let _ARM64_INS_CPYMWTN = 236;;
let _ARM64_INS_CPYMWTRN = 237;;
let _ARM64_INS_CPYMWTWN = 238;;
let _ARM64_INS_CPYP = 239;;
let _ARM64_INS_CPYPN = 240;;
let _ARM64_INS_CPYPRN = 241;;
let _ARM64_INS_CPYPRT = 242;;
let _ARM64_INS_CPYPRTN = 243;;
let _ARM64_INS_CPYPRTRN = 244;;
let _ARM64_INS_CPYPRTWN = 245;;
let _ARM64_INS_CPYPT = 246;;
let _ARM64_INS_CPYPTN = 247;;
let _ARM64_INS_CPYPTRN = 248;;
let _ARM64_INS_CPYPTWN = 249;;
let _ARM64_INS_CPYPWN = 250;;
let _ARM64_INS_CPYPWT = 251;;
let _ARM64_INS_CPYPWTN = 252;;
let _ARM64_INS_CPYPWTRN = 253;;
let _ARM64_INS_CPYPWTWN = 254;;
let _ARM64_INS_CRC32B = 255;;
let _ARM64_INS_CRC32CB = 256;;
let _ARM64_INS_CRC32CH = 257;;
let _ARM64_INS_CRC32CW = 258;;
let _ARM64_INS_CRC32CX = 259;;
let _ARM64_INS_CRC32H = 260;;
let _ARM64_INS_CRC32W = 261;;
let _ARM64_INS_CRC32X = 262;;
let _ARM64_INS_CSDB = 263;;
let _ARM64_INS_CSEL = 264;;
let _ARM64_INS_CSET = 265;;
let _ARM64_INS_CSETM = 266;;
let _ARM64_INS_CSINC = 267;;
let _ARM64_INS_CSINV = 268;;
let _ARM64_INS_CSNEG = 269;;
let _ARM64_INS_CTERMEQ = 270;;
let _ARM64_INS_CTERMNE = 271;;
let _ARM64_INS_DCPS1 = 272;;
let _ARM64_INS_DCPS2 = 273;;
let _ARM64_INS_DCPS3 = 274;;
let _ARM64_INS_DECB = 275;;
let _ARM64_INS_DECD = 276;;
let _ARM64_INS_DECH = 277;;
let _ARM64_INS_DECP = 278;;
let _ARM64_INS_DECW = 279;;
let _ARM64_INS_DFB = 280;;
let _ARM64_INS_DGH = 281;;
let _ARM64_INS_DMB = 282;;
let _ARM64_INS_DRPS = 283;;
let _ARM64_INS_DSB = 284;;
let _ARM64_INS_DUP = 285;;
let _ARM64_INS_DUPM = 286;;
let _ARM64_INS_EON = 287;;
let _ARM64_INS_EOR = 288;;
let _ARM64_INS_EOR3 = 289;;
let _ARM64_INS_EORBT = 290;;
let _ARM64_INS_EORS = 291;;
let _ARM64_INS_EORTB = 292;;
let _ARM64_INS_EORV = 293;;
let _ARM64_INS_ERET = 294;;
let _ARM64_INS_ERETAA = 295;;
let _ARM64_INS_ERETAB = 296;;
let _ARM64_INS_ESB = 297;;
let _ARM64_INS_EXT = 298;;
let _ARM64_INS_EXTR = 299;;
let _ARM64_INS_FABD = 300;;
let _ARM64_INS_FABS = 301;;
let _ARM64_INS_FACGE = 302;;
let _ARM64_INS_FACGT = 303;;
let _ARM64_INS_FACLE = 304;;
let _ARM64_INS_FACLT = 305;;
let _ARM64_INS_FADD = 306;;
let _ARM64_INS_FADDA = 307;;
let _ARM64_INS_FADDP = 308;;
let _ARM64_INS_FADDV = 309;;
let _ARM64_INS_FCADD = 310;;
let _ARM64_INS_FCCMP = 311;;
let _ARM64_INS_FCCMPE = 312;;
let _ARM64_INS_FCMEQ = 313;;
let _ARM64_INS_FCMGE = 314;;
let _ARM64_INS_FCMGT = 315;;
let _ARM64_INS_FCMLA = 316;;
let _ARM64_INS_FCMLE = 317;;
let _ARM64_INS_FCMLT = 318;;
let _ARM64_INS_FCMNE = 319;;
let _ARM64_INS_FCMP = 320;;
let _ARM64_INS_FCMPE = 321;;
let _ARM64_INS_FCMUO = 322;;
let _ARM64_INS_FCPY = 323;;
let _ARM64_INS_FCSEL = 324;;
let _ARM64_INS_FCVT = 325;;
let _ARM64_INS_FCVTAS = 326;;
let _ARM64_INS_FCVTAU = 327;;
let _ARM64_INS_FCVTL = 328;;
let _ARM64_INS_FCVTL2 = 329;;
let _ARM64_INS_FCVTLT = 330;;
let _ARM64_INS_FCVTMS = 331;;
let _ARM64_INS_FCVTMU = 332;;
let _ARM64_INS_FCVTN = 333;;
let _ARM64_INS_FCVTN2 = 334;;
let _ARM64_INS_FCVTNS = 335;;
let _ARM64_INS_FCVTNT = 336;;
let _ARM64_INS_FCVTNU = 337;;
let _ARM64_INS_FCVTPS = 338;;
let _ARM64_INS_FCVTPU = 339;;
let _ARM64_INS_FCVTX = 340;;
let _ARM64_INS_FCVTXN = 341;;
let _ARM64_INS_FCVTXN2 = 342;;
let _ARM64_INS_FCVTXNT = 343;;
let _ARM64_INS_FCVTZS = 344;;
let _ARM64_INS_FCVTZU = 345;;
let _ARM64_INS_FDIV = 346;;
let _ARM64_INS_FDIVR = 347;;
let _ARM64_INS_FDUP = 348;;
let _ARM64_INS_FEXPA = 349;;
let _ARM64_INS_FJCVTZS = 350;;
let _ARM64_INS_FLOGB = 351;;
let _ARM64_INS_FMAD = 352;;
let _ARM64_INS_FMADD = 353;;
let _ARM64_INS_FMAX = 354;;
let _ARM64_INS_FMAXNM = 355;;
let _ARM64_INS_FMAXNMP = 356;;
let _ARM64_INS_FMAXNMV = 357;;
let _ARM64_INS_FMAXP = 358;;
let _ARM64_INS_FMAXV = 359;;
let _ARM64_INS_FMIN = 360;;
let _ARM64_INS_FMINNM = 361;;
let _ARM64_INS_FMINNMP = 362;;
let _ARM64_INS_FMINNMV = 363;;
let _ARM64_INS_FMINP = 364;;
let _ARM64_INS_FMINV = 365;;
let _ARM64_INS_FMLA = 366;;
let _ARM64_INS_FMLAL = 367;;
let _ARM64_INS_FMLAL2 = 368;;
let _ARM64_INS_FMLALB = 369;;
let _ARM64_INS_FMLALT = 370;;
let _ARM64_INS_FMLS = 371;;
let _ARM64_INS_FMLSL = 372;;
let _ARM64_INS_FMLSL2 = 373;;
let _ARM64_INS_FMLSLB = 374;;
let _ARM64_INS_FMLSLT = 375;;
let _ARM64_INS_FMMLA = 376;;
let _ARM64_INS_FMOPA = 377;;
let _ARM64_INS_FMOPS = 378;;
let _ARM64_INS_FMOV = 379;;
let _ARM64_INS_FMSB = 380;;
let _ARM64_INS_FMSUB = 381;;
let _ARM64_INS_FMUL = 382;;
let _ARM64_INS_FMULX = 383;;
let _ARM64_INS_FNEG = 384;;
let _ARM64_INS_FNMAD = 385;;
let _ARM64_INS_FNMADD = 386;;
let _ARM64_INS_FNMLA = 387;;
let _ARM64_INS_FNMLS = 388;;
let _ARM64_INS_FNMSB = 389;;
let _ARM64_INS_FNMSUB = 390;;
let _ARM64_INS_FNMUL = 391;;
let _ARM64_INS_FRECPE = 392;;
let _ARM64_INS_FRECPS = 393;;
let _ARM64_INS_FRECPX = 394;;
let _ARM64_INS_FRINT32X = 395;;
let _ARM64_INS_FRINT32Z = 396;;
let _ARM64_INS_FRINT64X = 397;;
let _ARM64_INS_FRINT64Z = 398;;
let _ARM64_INS_FRINTA = 399;;
let _ARM64_INS_FRINTI = 400;;
let _ARM64_INS_FRINTM = 401;;
let _ARM64_INS_FRINTN = 402;;
let _ARM64_INS_FRINTP = 403;;
let _ARM64_INS_FRINTX = 404;;
let _ARM64_INS_FRINTZ = 405;;
let _ARM64_INS_FRSQRTE = 406;;
let _ARM64_INS_FRSQRTS = 407;;
let _ARM64_INS_FSCALE = 408;;
let _ARM64_INS_FSQRT = 409;;
let _ARM64_INS_FSUB = 410;;
let _ARM64_INS_FSUBR = 411;;
let _ARM64_INS_FTMAD = 412;;
let _ARM64_INS_FTSMUL = 413;;
let _ARM64_INS_FTSSEL = 414;;
let _ARM64_INS_GMI = 415;;
let _ARM64_INS_HINT = 416;;
let _ARM64_INS_HISTCNT = 417;;
let _ARM64_INS_HISTSEG = 418;;
let _ARM64_INS_HLT = 419;;
let _ARM64_INS_HVC = 420;;
let _ARM64_INS_INCB = 421;;
let _ARM64_INS_INCD = 422;;
let _ARM64_INS_INCH = 423;;
let _ARM64_INS_INCP = 424;;
let _ARM64_INS_INCW = 425;;
let _ARM64_INS_INDEX = 426;;
let _ARM64_INS_INS = 427;;
let _ARM64_INS_INSR = 428;;
let _ARM64_INS_IRG = 429;;
let _ARM64_INS_ISB = 430;;
let _ARM64_INS_LASTA = 431;;
let _ARM64_INS_LASTB = 432;;
let _ARM64_INS_LD1 = 433;;
let _ARM64_INS_LD1B = 434;;
let _ARM64_INS_LD1D = 435;;
let _ARM64_INS_LD1H = 436;;
let _ARM64_INS_LD1Q = 437;;
let _ARM64_INS_LD1R = 438;;
let _ARM64_INS_LD1RB = 439;;
let _ARM64_INS_LD1RD = 440;;
let _ARM64_INS_LD1RH = 441;;
let _ARM64_INS_LD1ROB = 442;;
let _ARM64_INS_LD1ROD = 443;;
let _ARM64_INS_LD1ROH = 444;;
let _ARM64_INS_LD1ROW = 445;;
let _ARM64_INS_LD1RQB = 446;;
let _ARM64_INS_LD1RQD = 447;;
let _ARM64_INS_LD1RQH = 448;;
let _ARM64_INS_LD1RQW = 449;;
let _ARM64_INS_LD1RSB = 450;;
let _ARM64_INS_LD1RSH = 451;;
let _ARM64_INS_LD1RSW = 452;;
let _ARM64_INS_LD1RW = 453;;
let _ARM64_INS_LD1SB = 454;;
let _ARM64_INS_LD1SH = 455;;
let _ARM64_INS_LD1SW = 456;;
let _ARM64_INS_LD1W = 457;;
let _ARM64_INS_LD2 = 458;;
let _ARM64_INS_LD2B = 459;;
let _ARM64_INS_LD2D = 460;;
let _ARM64_INS_LD2H = 461;;
let _ARM64_INS_LD2R = 462;;
let _ARM64_INS_LD2W = 463;;
let _ARM64_INS_LD3 = 464;;
let _ARM64_INS_LD3B = 465;;
let _ARM64_INS_LD3D = 466;;
let _ARM64_INS_LD3H = 467;;
let _ARM64_INS_LD3R = 468;;
let _ARM64_INS_LD3W = 469;;
let _ARM64_INS_LD4 = 470;;
let _ARM64_INS_LD4B = 471;;
let _ARM64_INS_LD4D = 472;;
let _ARM64_INS_LD4H = 473;;
let _ARM64_INS_LD4R = 474;;
let _ARM64_INS_LD4W = 475;;
let _ARM64_INS_LD64B = 476;;
let _ARM64_INS_LDADD = 477;;
let _ARM64_INS_LDADDA = 478;;
let _ARM64_INS_LDADDAB = 479;;
let _ARM64_INS_LDADDAH = 480;;
let _ARM64_INS_LDADDAL = 481;;
let _ARM64_INS_LDADDALB = 482;;
let _ARM64_INS_LDADDALH = 483;;
let _ARM64_INS_LDADDB = 484;;
let _ARM64_INS_LDADDH = 485;;
let _ARM64_INS_LDADDL = 486;;
let _ARM64_INS_LDADDLB = 487;;
let _ARM64_INS_LDADDLH = 488;;
let _ARM64_INS_LDAPR = 489;;
let _ARM64_INS_LDAPRB = 490;;
let _ARM64_INS_LDAPRH = 491;;
let _ARM64_INS_LDAPUR = 492;;
let _ARM64_INS_LDAPURB = 493;;
let _ARM64_INS_LDAPURH = 494;;
let _ARM64_INS_LDAPURSB = 495;;
let _ARM64_INS_LDAPURSH = 496;;
let _ARM64_INS_LDAPURSW = 497;;
let _ARM64_INS_LDAR = 498;;
let _ARM64_INS_LDARB = 499;;
let _ARM64_INS_LDARH = 500;;
let _ARM64_INS_LDAXP = 501;;
let _ARM64_INS_LDAXR = 502;;
let _ARM64_INS_LDAXRB = 503;;
let _ARM64_INS_LDAXRH = 504;;
let _ARM64_INS_LDCLR = 505;;
let _ARM64_INS_LDCLRA = 506;;
let _ARM64_INS_LDCLRAB = 507;;
let _ARM64_INS_LDCLRAH = 508;;
let _ARM64_INS_LDCLRAL = 509;;
let _ARM64_INS_LDCLRALB = 510;;
let _ARM64_INS_LDCLRALH = 511;;
let _ARM64_INS_LDCLRB = 512;;
let _ARM64_INS_LDCLRH = 513;;
let _ARM64_INS_LDCLRL = 514;;
let _ARM64_INS_LDCLRLB = 515;;
let _ARM64_INS_LDCLRLH = 516;;
let _ARM64_INS_LDEOR = 517;;
let _ARM64_INS_LDEORA = 518;;
let _ARM64_INS_LDEORAB = 519;;
let _ARM64_INS_LDEORAH = 520;;
let _ARM64_INS_LDEORAL = 521;;
let _ARM64_INS_LDEORALB = 522;;
let _ARM64_INS_LDEORALH = 523;;
let _ARM64_INS_LDEORB = 524;;
let _ARM64_INS_LDEORH = 525;;
let _ARM64_INS_LDEORL = 526;;
let _ARM64_INS_LDEORLB = 527;;
let _ARM64_INS_LDEORLH = 528;;
let _ARM64_INS_LDFF1B = 529;;
let _ARM64_INS_LDFF1D = 530;;
let _ARM64_INS_LDFF1H = 531;;
let _ARM64_INS_LDFF1SB = 532;;
let _ARM64_INS_LDFF1SH = 533;;
let _ARM64_INS_LDFF1SW = 534;;
let _ARM64_INS_LDFF1W = 535;;
let _ARM64_INS_LDG = 536;;
let _ARM64_INS_LDGM = 537;;
let _ARM64_INS_LDLAR = 538;;
let _ARM64_INS_LDLARB = 539;;
let _ARM64_INS_LDLARH = 540;;
let _ARM64_INS_LDNF1B = 541;;
let _ARM64_INS_LDNF1D = 542;;
let _ARM64_INS_LDNF1H = 543;;
let _ARM64_INS_LDNF1SB = 544;;
let _ARM64_INS_LDNF1SH = 545;;
let _ARM64_INS_LDNF1SW = 546;;
let _ARM64_INS_LDNF1W = 547;;
let _ARM64_INS_LDNP = 548;;
let _ARM64_INS_LDNT1B = 549;;
let _ARM64_INS_LDNT1D = 550;;
let _ARM64_INS_LDNT1H = 551;;
let _ARM64_INS_LDNT1SB = 552;;
let _ARM64_INS_LDNT1SH = 553;;
let _ARM64_INS_LDNT1SW = 554;;
let _ARM64_INS_LDNT1W = 555;;
let _ARM64_INS_LDP = 556;;
let _ARM64_INS_LDPSW = 557;;
let _ARM64_INS_LDR = 558;;
let _ARM64_INS_LDRAA = 559;;
let _ARM64_INS_LDRAB = 560;;
let _ARM64_INS_LDRB = 561;;
let _ARM64_INS_LDRH = 562;;
let _ARM64_INS_LDRSB = 563;;
let _ARM64_INS_LDRSH = 564;;
let _ARM64_INS_LDRSW = 565;;
let _ARM64_INS_LDSET = 566;;
let _ARM64_INS_LDSETA = 567;;
let _ARM64_INS_LDSETAB = 568;;
let _ARM64_INS_LDSETAH = 569;;
let _ARM64_INS_LDSETAL = 570;;
let _ARM64_INS_LDSETALB = 571;;
let _ARM64_INS_LDSETALH = 572;;
let _ARM64_INS_LDSETB = 573;;
let _ARM64_INS_LDSETH = 574;;
let _ARM64_INS_LDSETL = 575;;
let _ARM64_INS_LDSETLB = 576;;
let _ARM64_INS_LDSETLH = 577;;
let _ARM64_INS_LDSMAX = 578;;
let _ARM64_INS_LDSMAXA = 579;;
let _ARM64_INS_LDSMAXAB = 580;;
let _ARM64_INS_LDSMAXAH = 581;;
let _ARM64_INS_LDSMAXAL = 582;;
let _ARM64_INS_LDSMAXALB = 583;;
let _ARM64_INS_LDSMAXALH = 584;;
let _ARM64_INS_LDSMAXB = 585;;
let _ARM64_INS_LDSMAXH = 586;;
let _ARM64_INS_LDSMAXL = 587;;
let _ARM64_INS_LDSMAXLB = 588;;
let _ARM64_INS_LDSMAXLH = 589;;
let _ARM64_INS_LDSMIN = 590;;
let _ARM64_INS_LDSMINA = 591;;
let _ARM64_INS_LDSMINAB = 592;;
let _ARM64_INS_LDSMINAH = 593;;
let _ARM64_INS_LDSMINAL = 594;;
let _ARM64_INS_LDSMINALB = 595;;
let _ARM64_INS_LDSMINALH = 596;;
let _ARM64_INS_LDSMINB = 597;;
let _ARM64_INS_LDSMINH = 598;;
let _ARM64_INS_LDSMINL = 599;;
let _ARM64_INS_LDSMINLB = 600;;
let _ARM64_INS_LDSMINLH = 601;;
let _ARM64_INS_LDTR = 602;;
let _ARM64_INS_LDTRB = 603;;
let _ARM64_INS_LDTRH = 604;;
let _ARM64_INS_LDTRSB = 605;;
let _ARM64_INS_LDTRSH = 606;;
let _ARM64_INS_LDTRSW = 607;;
let _ARM64_INS_LDUMAX = 608;;
let _ARM64_INS_LDUMAXA = 609;;
let _ARM64_INS_LDUMAXAB = 610;;
let _ARM64_INS_LDUMAXAH = 611;;
let _ARM64_INS_LDUMAXAL = 612;;
let _ARM64_INS_LDUMAXALB = 613;;
let _ARM64_INS_LDUMAXALH = 614;;
let _ARM64_INS_LDUMAXB = 615;;
let _ARM64_INS_LDUMAXH = 616;;
let _ARM64_INS_LDUMAXL = 617;;
let _ARM64_INS_LDUMAXLB = 618;;
let _ARM64_INS_LDUMAXLH = 619;;
let _ARM64_INS_LDUMIN = 620;;
let _ARM64_INS_LDUMINA = 621;;
let _ARM64_INS_LDUMINAB = 622;;
let _ARM64_INS_LDUMINAH = 623;;
let _ARM64_INS_LDUMINAL = 624;;
let _ARM64_INS_LDUMINALB = 625;;
let _ARM64_INS_LDUMINALH = 626;;
let _ARM64_INS_LDUMINB = 627;;
let _ARM64_INS_LDUMINH = 628;;
let _ARM64_INS_LDUMINL = 629;;
let _ARM64_INS_LDUMINLB = 630;;
let _ARM64_INS_LDUMINLH = 631;;
let _ARM64_INS_LDUR = 632;;
let _ARM64_INS_LDURB = 633;;
let _ARM64_INS_LDURH = 634;;
let _ARM64_INS_LDURSB = 635;;
let _ARM64_INS_LDURSH = 636;;
let _ARM64_INS_LDURSW = 637;;
let _ARM64_INS_LDXP = 638;;
let _ARM64_INS_LDXR = 639;;
let _ARM64_INS_LDXRB = 640;;
let _ARM64_INS_LDXRH = 641;;
let _ARM64_INS_LSL = 642;;
let _ARM64_INS_LSLR = 643;;
let _ARM64_INS_LSLV = 644;;
let _ARM64_INS_LSR = 645;;
let _ARM64_INS_LSRR = 646;;
let _ARM64_INS_LSRV = 647;;
let _ARM64_INS_MAD = 648;;
let _ARM64_INS_MADD = 649;;
let _ARM64_INS_MATCH = 650;;
let _ARM64_INS_MLA = 651;;
let _ARM64_INS_MLS = 652;;
let _ARM64_INS_MNEG = 653;;
let _ARM64_INS_MOV = 654;;
let _ARM64_INS_MOVA = 655;;
let _ARM64_INS_MOVI = 656;;
let _ARM64_INS_MOVK = 657;;
let _ARM64_INS_MOVN = 658;;
let _ARM64_INS_MOVPRFX = 659;;
let _ARM64_INS_MOVS = 660;;
let _ARM64_INS_MOVZ = 661;;
let _ARM64_INS_MRS = 662;;
let _ARM64_INS_MSB = 663;;
let _ARM64_INS_MSR = 664;;
let _ARM64_INS_MSUB = 665;;
let _ARM64_INS_MUL = 666;;
let _ARM64_INS_MVN = 667;;
let _ARM64_INS_MVNI = 668;;
let _ARM64_INS_NAND = 669;;
let _ARM64_INS_NANDS = 670;;
let _ARM64_INS_NBSL = 671;;
let _ARM64_INS_NEG = 672;;
let _ARM64_INS_NEGS = 673;;
let _ARM64_INS_NGC = 674;;
let _ARM64_INS_NGCS = 675;;
let _ARM64_INS_NMATCH = 676;;
let _ARM64_INS_NOP = 677;;
let _ARM64_INS_NOR = 678;;
let _ARM64_INS_NORS = 679;;
let _ARM64_INS_NOT = 680;;
let _ARM64_INS_NOTS = 681;;
let _ARM64_INS_ORN = 682;;
let _ARM64_INS_ORNS = 683;;
let _ARM64_INS_ORR = 684;;
let _ARM64_INS_ORRS = 685;;
let _ARM64_INS_ORV = 686;;
let _ARM64_INS_PACDA = 687;;
let _ARM64_INS_PACDB = 688;;
let _ARM64_INS_PACDZA = 689;;
let _ARM64_INS_PACDZB = 690;;
let _ARM64_INS_PACGA = 691;;
let _ARM64_INS_PACIA = 692;;
let _ARM64_INS_PACIA1716 = 693;;
let _ARM64_INS_PACIASP = 694;;
let _ARM64_INS_PACIAZ = 695;;
let _ARM64_INS_PACIB = 696;;
let _ARM64_INS_PACIB1716 = 697;;
let _ARM64_INS_PACIBSP = 698;;
let _ARM64_INS_PACIBZ = 699;;
let _ARM64_INS_PACIZA = 700;;
let _ARM64_INS_PACIZB = 701;;
let _ARM64_INS_PFALSE = 702;;
let _ARM64_INS_PFIRST = 703;;
let _ARM64_INS_PMUL = 704;;
let _ARM64_INS_PMULL = 705;;
let _ARM64_INS_PMULL2 = 706;;
let _ARM64_INS_PMULLB = 707;;
let _ARM64_INS_PMULLT = 708;;
let _ARM64_INS_PNEXT = 709;;
let _ARM64_INS_PRFB = 710;;
let _ARM64_INS_PRFD = 711;;
let _ARM64_INS_PRFH = 712;;
let _ARM64_INS_PRFM = 713;;
let _ARM64_INS_PRFUM = 714;;
let _ARM64_INS_PRFW = 715;;
let _ARM64_INS_PSB = 716;;
let _ARM64_INS_PSEL = 717;;
let _ARM64_INS_PSSBB = 718;;
let _ARM64_INS_PTEST = 719;;
let _ARM64_INS_PTRUE = 720;;
let _ARM64_INS_PTRUES = 721;;
let _ARM64_INS_PUNPKHI = 722;;
let _ARM64_INS_PUNPKLO = 723;;
let _ARM64_INS_RADDHN = 724;;
let _ARM64_INS_RADDHN2 = 725;;
let _ARM64_INS_RADDHNB = 726;;
let _ARM64_INS_RADDHNT = 727;;
let _ARM64_INS_RAX1 = 728;;
let _ARM64_INS_RBIT = 729;;
let _ARM64_INS_RDFFR = 730;;
let _ARM64_INS_RDFFRS = 731;;
let _ARM64_INS_RDVL = 732;;
let _ARM64_INS_RET = 733;;
let _ARM64_INS_RETAA = 734;;
let _ARM64_INS_RETAB = 735;;
let _ARM64_INS_REV = 736;;
let _ARM64_INS_REV16 = 737;;
let _ARM64_INS_REV32 = 738;;
let _ARM64_INS_REV64 = 739;;
let _ARM64_INS_REVB = 740;;
let _ARM64_INS_REVD = 741;;
let _ARM64_INS_REVH = 742;;
let _ARM64_INS_REVW = 743;;
let _ARM64_INS_RMIF = 744;;
let _ARM64_INS_ROR = 745;;
let _ARM64_INS_RORV = 746;;
let _ARM64_INS_RSHRN = 747;;
let _ARM64_INS_RSHRN2 = 748;;
let _ARM64_INS_RSHRNB = 749;;
let _ARM64_INS_RSHRNT = 750;;
let _ARM64_INS_RSUBHN = 751;;
let _ARM64_INS_RSUBHN2 = 752;;
let _ARM64_INS_RSUBHNB = 753;;
let _ARM64_INS_RSUBHNT = 754;;
let _ARM64_INS_SABA = 755;;
let _ARM64_INS_SABAL = 756;;
let _ARM64_INS_SABAL2 = 757;;
let _ARM64_INS_SABALB = 758;;
let _ARM64_INS_SABALT = 759;;
let _ARM64_INS_SABD = 760;;
let _ARM64_INS_SABDL = 761;;
let _ARM64_INS_SABDL2 = 762;;
let _ARM64_INS_SABDLB = 763;;
let _ARM64_INS_SABDLT = 764;;
let _ARM64_INS_SADALP = 765;;
let _ARM64_INS_SADDL = 766;;
let _ARM64_INS_SADDL2 = 767;;
let _ARM64_INS_SADDLB = 768;;
let _ARM64_INS_SADDLBT = 769;;
let _ARM64_INS_SADDLP = 770;;
let _ARM64_INS_SADDLT = 771;;
let _ARM64_INS_SADDLV = 772;;
let _ARM64_INS_SADDV = 773;;
let _ARM64_INS_SADDW = 774;;
let _ARM64_INS_SADDW2 = 775;;
let _ARM64_INS_SADDWB = 776;;
let _ARM64_INS_SADDWT = 777;;
let _ARM64_INS_SB = 778;;
let _ARM64_INS_SBC = 779;;
let _ARM64_INS_SBCLB = 780;;
let _ARM64_INS_SBCLT = 781;;
let _ARM64_INS_SBCS = 782;;
let _ARM64_INS_SBFM = 783;;
let _ARM64_INS_SCLAMP = 784;;
let _ARM64_INS_SCVTF = 785;;
let _ARM64_INS_SDIV = 786;;
let _ARM64_INS_SDIVR = 787;;
let _ARM64_INS_SDOT = 788;;
let _ARM64_INS_SEL = 789;;
let _ARM64_INS_SETE = 790;;
let _ARM64_INS_SETEN = 791;;
let _ARM64_INS_SETET = 792;;
let _ARM64_INS_SETETN = 793;;
let _ARM64_INS_SETF16 = 794;;
let _ARM64_INS_SETF8 = 795;;
let _ARM64_INS_SETFFR = 796;;
let _ARM64_INS_SETGE = 797;;
let _ARM64_INS_SETGEN = 798;;
let _ARM64_INS_SETGET = 799;;
let _ARM64_INS_SETGETN = 800;;
let _ARM64_INS_SETGM = 801;;
let _ARM64_INS_SETGMN = 802;;
let _ARM64_INS_SETGMT = 803;;
let _ARM64_INS_SETGMTN = 804;;
let _ARM64_INS_SETGP = 805;;
let _ARM64_INS_SETGPN = 806;;
let _ARM64_INS_SETGPT = 807;;
let _ARM64_INS_SETGPTN = 808;;
let _ARM64_INS_SETM = 809;;
let _ARM64_INS_SETMN = 810;;
let _ARM64_INS_SETMT = 811;;
let _ARM64_INS_SETMTN = 812;;
let _ARM64_INS_SETP = 813;;
let _ARM64_INS_SETPN = 814;;
let _ARM64_INS_SETPT = 815;;
let _ARM64_INS_SETPTN = 816;;
let _ARM64_INS_SEV = 817;;
let _ARM64_INS_SEVL = 818;;
let _ARM64_INS_SHA1C = 819;;
let _ARM64_INS_SHA1H = 820;;
let _ARM64_INS_SHA1M = 821;;
let _ARM64_INS_SHA1P = 822;;
let _ARM64_INS_SHA1SU0 = 823;;
let _ARM64_INS_SHA1SU1 = 824;;
let _ARM64_INS_SHA256H = 825;;
let _ARM64_INS_SHA256H2 = 826;;
let _ARM64_INS_SHA256SU0 = 827;;
let _ARM64_INS_SHA256SU1 = 828;;
let _ARM64_INS_SHA512H = 829;;
let _ARM64_INS_SHA512H2 = 830;;
let _ARM64_INS_SHA512SU0 = 831;;
let _ARM64_INS_SHA512SU1 = 832;;
let _ARM64_INS_SHADD = 833;;
let _ARM64_INS_SHL = 834;;
let _ARM64_INS_SHLL = 835;;
let _ARM64_INS_SHLL2 = 836;;
let _ARM64_INS_SHRN = 837;;
let _ARM64_INS_SHRN2 = 838;;
let _ARM64_INS_SHRNB = 839;;
let _ARM64_INS_SHRNT = 840;;
let _ARM64_INS_SHSUB = 841;;
let _ARM64_INS_SHSUBR = 842;;
let _ARM64_INS_SLI = 843;;
let _ARM64_INS_SM3PARTW1 = 844;;
let _ARM64_INS_SM3PARTW2 = 845;;
let _ARM64_INS_SM3SS1 = 846;;
let _ARM64_INS_SM3TT1A = 847;;
let _ARM64_INS_SM3TT1B = 848;;
let _ARM64_INS_SM3TT2A = 849;;
let _ARM64_INS_SM3TT2B = 850;;
let _ARM64_INS_SM4E = 851;;
let _ARM64_INS_SM4EKEY = 852;;
let _ARM64_INS_SMADDL = 853;;
let _ARM64_INS_SMAX = 854;;
let _ARM64_INS_SMAXP = 855;;
let _ARM64_INS_SMAXV = 856;;
let _ARM64_INS_SMC = 857;;
let _ARM64_INS_SMIN = 858;;
let _ARM64_INS_SMINP = 859;;
let _ARM64_INS_SMINV = 860;;
let _ARM64_INS_SMLAL = 861;;
let _ARM64_INS_SMLAL2 = 862;;
let _ARM64_INS_SMLALB = 863;;
let _ARM64_INS_SMLALT = 864;;
let _ARM64_INS_SMLSL = 865;;
let _ARM64_INS_SMLSL2 = 866;;
let _ARM64_INS_SMLSLB = 867;;
let _ARM64_INS_SMLSLT = 868;;
let _ARM64_INS_SMMLA = 869;;
let _ARM64_INS_SMNEGL = 870;;
let _ARM64_INS_SMOPA = 871;;
let _ARM64_INS_SMOPS = 872;;
let _ARM64_INS_SMOV = 873;;
let _ARM64_INS_SMSTART = 874;;
let _ARM64_INS_SMSTOP = 875;;
let _ARM64_INS_SMSUBL = 876;;
let _ARM64_INS_SMULH = 877;;
let _ARM64_INS_SMULL = 878;;
let _ARM64_INS_SMULL2 = 879;;
let _ARM64_INS_SMULLB = 880;;
let _ARM64_INS_SMULLT = 881;;
let _ARM64_INS_SPLICE = 882;;
let _ARM64_INS_SQABS = 883;;
let _ARM64_INS_SQADD = 884;;
let _ARM64_INS_SQCADD = 885;;
let _ARM64_INS_SQDECB = 886;;
let _ARM64_INS_SQDECD = 887;;
let _ARM64_INS_SQDECH = 888;;
let _ARM64_INS_SQDECP = 889;;
let _ARM64_INS_SQDECW = 890;;
let _ARM64_INS_SQDMLAL = 891;;
let _ARM64_INS_SQDMLAL2 = 892;;
let _ARM64_INS_SQDMLALB = 893;;
let _ARM64_INS_SQDMLALBT = 894;;
let _ARM64_INS_SQDMLALT = 895;;
let _ARM64_INS_SQDMLSL = 896;;
let _ARM64_INS_SQDMLSL2 = 897;;
let _ARM64_INS_SQDMLSLB = 898;;
let _ARM64_INS_SQDMLSLBT = 899;;
let _ARM64_INS_SQDMLSLT = 900;;
let _ARM64_INS_SQDMULH = 901;;
let _ARM64_INS_SQDMULL = 902;;
let _ARM64_INS_SQDMULL2 = 903;;
let _ARM64_INS_SQDMULLB = 904;;
let _ARM64_INS_SQDMULLT = 905;;
let _ARM64_INS_SQINCB = 906;;
let _ARM64_INS_SQINCD = 907;;
let _ARM64_INS_SQINCH = 908;;
let _ARM64_INS_SQINCP = 909;;
let _ARM64_INS_SQINCW = 910;;
let _ARM64_INS_SQNEG = 911;;
let _ARM64_INS_SQRDCMLAH = 912;;
let _ARM64_INS_SQRDMLAH = 913;;
let _ARM64_INS_SQRDMLSH = 914;;
let _ARM64_INS_SQRDMULH = 915;;
let _ARM64_INS_SQRSHL = 916;;
let _ARM64_INS_SQRSHLR = 917;;
let _ARM64_INS_SQRSHRN = 918;;
let _ARM64_INS_SQRSHRN2 = 919;;
let _ARM64_INS_SQRSHRNB = 920;;
let _ARM64_INS_SQRSHRNT = 921;;
let _ARM64_INS_SQRSHRUN = 922;;
let _ARM64_INS_SQRSHRUN2 = 923;;
let _ARM64_INS_SQRSHRUNB = 924;;
let _ARM64_INS_SQRSHRUNT = 925;;
let _ARM64_INS_SQSHL = 926;;
let _ARM64_INS_SQSHLR = 927;;
let _ARM64_INS_SQSHLU = 928;;
let _ARM64_INS_SQSHRN = 929;;
let _ARM64_INS_SQSHRN2 = 930;;
let _ARM64_INS_SQSHRNB = 931;;
let _ARM64_INS_SQSHRNT = 932;;
let _ARM64_INS_SQSHRUN = 933;;
let _ARM64_INS_SQSHRUN2 = 934;;
let _ARM64_INS_SQSHRUNB = 935;;
let _ARM64_INS_SQSHRUNT = 936;;
let _ARM64_INS_SQSUB = 937;;
let _ARM64_INS_SQSUBR = 938;;
let _ARM64_INS_SQXTN = 939;;
let _ARM64_INS_SQXTN2 = 940;;
let _ARM64_INS_SQXTNB = 941;;
let _ARM64_INS_SQXTNT = 942;;
let _ARM64_INS_SQXTUN = 943;;
let _ARM64_INS_SQXTUN2 = 944;;
let _ARM64_INS_SQXTUNB = 945;;
let _ARM64_INS_SQXTUNT = 946;;
let _ARM64_INS_SRHADD = 947;;
let _ARM64_INS_SRI = 948;;
let _ARM64_INS_SRSHL = 949;;
let _ARM64_INS_SRSHLR = 950;;
let _ARM64_INS_SRSHR = 951;;
let _ARM64_INS_SRSRA = 952;;
let _ARM64_INS_SSBB = 953;;
let _ARM64_INS_SSHL = 954;;
let _ARM64_INS_SSHLL = 955;;
let _ARM64_INS_SSHLL2 = 956;;
let _ARM64_INS_SSHLLB = 957;;
let _ARM64_INS_SSHLLT = 958;;
let _ARM64_INS_SSHR = 959;;
let _ARM64_INS_SSRA = 960;;
let _ARM64_INS_SSUBL = 961;;
let _ARM64_INS_SSUBL2 = 962;;
let _ARM64_INS_SSUBLB = 963;;
let _ARM64_INS_SSUBLBT = 964;;
let _ARM64_INS_SSUBLT = 965;;
let _ARM64_INS_SSUBLTB = 966;;
let _ARM64_INS_SSUBW = 967;;
let _ARM64_INS_SSUBW2 = 968;;
let _ARM64_INS_SSUBWB = 969;;
let _ARM64_INS_SSUBWT = 970;;
let _ARM64_INS_ST1 = 971;;
let _ARM64_INS_ST1B = 972;;
let _ARM64_INS_ST1D = 973;;
let _ARM64_INS_ST1H = 974;;
let _ARM64_INS_ST1Q = 975;;
let _ARM64_INS_ST1W = 976;;
let _ARM64_INS_ST2 = 977;;
let _ARM64_INS_ST2B = 978;;
let _ARM64_INS_ST2D = 979;;
let _ARM64_INS_ST2G = 980;;
let _ARM64_INS_ST2H = 981;;
let _ARM64_INS_ST2W = 982;;
let _ARM64_INS_ST3 = 983;;
let _ARM64_INS_ST3B = 984;;
let _ARM64_INS_ST3D = 985;;
let _ARM64_INS_ST3H = 986;;
let _ARM64_INS_ST3W = 987;;
let _ARM64_INS_ST4 = 988;;
let _ARM64_INS_ST4B = 989;;
let _ARM64_INS_ST4D = 990;;
let _ARM64_INS_ST4H = 991;;
let _ARM64_INS_ST4W = 992;;
let _ARM64_INS_ST64B = 993;;
let _ARM64_INS_ST64BV = 994;;
let _ARM64_INS_ST64BV0 = 995;;
let _ARM64_INS_STADD = 996;;
let _ARM64_INS_STADDB = 997;;
let _ARM64_INS_STADDH = 998;;
let _ARM64_INS_STADDL = 999;;
let _ARM64_INS_STADDLB = 1000;;
let _ARM64_INS_STADDLH = 1001;;
let _ARM64_INS_STCLR = 1002;;
let _ARM64_INS_STCLRB = 1003;;
let _ARM64_INS_STCLRH = 1004;;
let _ARM64_INS_STCLRL = 1005;;
let _ARM64_INS_STCLRLB = 1006;;
let _ARM64_INS_STCLRLH = 1007;;
let _ARM64_INS_STEOR = 1008;;
let _ARM64_INS_STEORB = 1009;;
let _ARM64_INS_STEORH = 1010;;
let _ARM64_INS_STEORL = 1011;;
let _ARM64_INS_STEORLB = 1012;;
let _ARM64_INS_STEORLH = 1013;;
let _ARM64_INS_STG = 1014;;
let _ARM64_INS_STGM = 1015;;
let _ARM64_INS_STGP = 1016;;
let _ARM64_INS_STLLR = 1017;;
let _ARM64_INS_STLLRB = 1018;;
let _ARM64_INS_STLLRH = 1019;;
let _ARM64_INS_STLR = 1020;;
let _ARM64_INS_STLRB = 1021;;
let _ARM64_INS_STLRH = 1022;;
let _ARM64_INS_STLUR = 1023;;
let _ARM64_INS_STLURB = 1024;;
let _ARM64_INS_STLURH = 1025;;
let _ARM64_INS_STLXP = 1026;;
let _ARM64_INS_STLXR = 1027;;
let _ARM64_INS_STLXRB = 1028;;
let _ARM64_INS_STLXRH = 1029;;
let _ARM64_INS_STNP = 1030;;
let _ARM64_INS_STNT1B = 1031;;
let _ARM64_INS_STNT1D = 1032;;
let _ARM64_INS_STNT1H = 1033;;
let _ARM64_INS_STNT1W = 1034;;
let _ARM64_INS_STP = 1035;;
let _ARM64_INS_STR = 1036;;
let _ARM64_INS_STRB = 1037;;
let _ARM64_INS_STRH = 1038;;
let _ARM64_INS_STSET = 1039;;
let _ARM64_INS_STSETB = 1040;;
let _ARM64_INS_STSETH = 1041;;
let _ARM64_INS_STSETL = 1042;;
let _ARM64_INS_STSETLB = 1043;;
let _ARM64_INS_STSETLH = 1044;;
let _ARM64_INS_STSMAX = 1045;;
let _ARM64_INS_STSMAXB = 1046;;
let _ARM64_INS_STSMAXH = 1047;;
let _ARM64_INS_STSMAXL = 1048;;
let _ARM64_INS_STSMAXLB = 1049;;
let _ARM64_INS_STSMAXLH = 1050;;
let _ARM64_INS_STSMIN = 1051;;
let _ARM64_INS_STSMINB = 1052;;
let _ARM64_INS_STSMINH = 1053;;
let _ARM64_INS_STSMINL = 1054;;
let _ARM64_INS_STSMINLB = 1055;;
let _ARM64_INS_STSMINLH = 1056;;
let _ARM64_INS_STTR = 1057;;
let _ARM64_INS_STTRB = 1058;;
let _ARM64_INS_STTRH = 1059;;
let _ARM64_INS_STUMAX = 1060;;
let _ARM64_INS_STUMAXB = 1061;;
let _ARM64_INS_STUMAXH = 1062;;
let _ARM64_INS_STUMAXL = 1063;;
let _ARM64_INS_STUMAXLB = 1064;;
let _ARM64_INS_STUMAXLH = 1065;;
let _ARM64_INS_STUMIN = 1066;;
let _ARM64_INS_STUMINB = 1067;;
let _ARM64_INS_STUMINH = 1068;;
let _ARM64_INS_STUMINL = 1069;;
let _ARM64_INS_STUMINLB = 1070;;
let _ARM64_INS_STUMINLH = 1071;;
let _ARM64_INS_STUR = 1072;;
let _ARM64_INS_STURB = 1073;;
let _ARM64_INS_STURH = 1074;;
let _ARM64_INS_STXP = 1075;;
let _ARM64_INS_STXR = 1076;;
let _ARM64_INS_STXRB = 1077;;
let _ARM64_INS_STXRH = 1078;;
let _ARM64_INS_STZ2G = 1079;;
let _ARM64_INS_STZG = 1080;;
let _ARM64_INS_STZGM = 1081;;
let _ARM64_INS_SUB = 1082;;
let _ARM64_INS_SUBG = 1083;;
let _ARM64_INS_SUBHN = 1084;;
let _ARM64_INS_SUBHN2 = 1085;;
let _ARM64_INS_SUBHNB = 1086;;
let _ARM64_INS_SUBHNT = 1087;;
let _ARM64_INS_SUBP = 1088;;
let _ARM64_INS_SUBPS = 1089;;
let _ARM64_INS_SUBR = 1090;;
let _ARM64_INS_SUBS = 1091;;
let _ARM64_INS_SUDOT = 1092;;
let _ARM64_INS_SUMOPA = 1093;;
let _ARM64_INS_SUMOPS = 1094;;
let _ARM64_INS_SUNPKHI = 1095;;
let _ARM64_INS_SUNPKLO = 1096;;
let _ARM64_INS_SUQADD = 1097;;
let _ARM64_INS_SVC = 1098;;
let _ARM64_INS_SWP = 1099;;
let _ARM64_INS_SWPA = 1100;;
let _ARM64_INS_SWPAB = 1101;;
let _ARM64_INS_SWPAH = 1102;;
let _ARM64_INS_SWPAL = 1103;;
let _ARM64_INS_SWPALB = 1104;;
let _ARM64_INS_SWPALH = 1105;;
let _ARM64_INS_SWPB = 1106;;
let _ARM64_INS_SWPH = 1107;;
let _ARM64_INS_SWPL = 1108;;
let _ARM64_INS_SWPLB = 1109;;
let _ARM64_INS_SWPLH = 1110;;
let _ARM64_INS_SXTB = 1111;;
let _ARM64_INS_SXTH = 1112;;
let _ARM64_INS_SXTL = 1113;;
let _ARM64_INS_SXTL2 = 1114;;
let _ARM64_INS_SXTW = 1115;;
let _ARM64_INS_SYS = 1116;;
let _ARM64_INS_SYSL = 1117;;
let _ARM64_INS_TBL = 1118;;
let _ARM64_INS_TBNZ = 1119;;
let _ARM64_INS_TBX = 1120;;
let _ARM64_INS_TBZ = 1121;;
let _ARM64_INS_TCANCEL = 1122;;
let _ARM64_INS_TCOMMIT = 1123;;
let _ARM64_INS_TRN1 = 1124;;
let _ARM64_INS_TRN2 = 1125;;
let _ARM64_INS_TSB = 1126;;
let _ARM64_INS_TST = 1127;;
let _ARM64_INS_TSTART = 1128;;
let _ARM64_INS_TTEST = 1129;;
let _ARM64_INS_UABA = 1130;;
let _ARM64_INS_UABAL = 1131;;
let _ARM64_INS_UABAL2 = 1132;;
let _ARM64_INS_UABALB = 1133;;
let _ARM64_INS_UABALT = 1134;;
let _ARM64_INS_UABD = 1135;;
let _ARM64_INS_UABDL = 1136;;
let _ARM64_INS_UABDL2 = 1137;;
let _ARM64_INS_UABDLB = 1138;;
let _ARM64_INS_UABDLT = 1139;;
let _ARM64_INS_UADALP = 1140;;
let _ARM64_INS_UADDL = 1141;;
let _ARM64_INS_UADDL2 = 1142;;
let _ARM64_INS_UADDLB = 1143;;
let _ARM64_INS_UADDLP = 1144;;
let _ARM64_INS_UADDLT = 1145;;
let _ARM64_INS_UADDLV = 1146;;
let _ARM64_INS_UADDV = 1147;;
let _ARM64_INS_UADDW = 1148;;
let _ARM64_INS_UADDW2 = 1149;;
let _ARM64_INS_UADDWB = 1150;;
let _ARM64_INS_UADDWT = 1151;;
let _ARM64_INS_UBFM = 1152;;
let _ARM64_INS_UCLAMP = 1153;;
let _ARM64_INS_UCVTF = 1154;;
let _ARM64_INS_UDF = 1155;;
let _ARM64_INS_UDIV = 1156;;
let _ARM64_INS_UDIVR = 1157;;
let _ARM64_INS_UDOT = 1158;;
let _ARM64_INS_UHADD = 1159;;
let _ARM64_INS_UHSUB = 1160;;
let _ARM64_INS_UHSUBR = 1161;;
let _ARM64_INS_UMADDL = 1162;;
let _ARM64_INS_UMAX = 1163;;
let _ARM64_INS_UMAXP = 1164;;
let _ARM64_INS_UMAXV = 1165;;
let _ARM64_INS_UMIN = 1166;;
let _ARM64_INS_UMINP = 1167;;
let _ARM64_INS_UMINV = 1168;;
let _ARM64_INS_UMLAL = 1169;;
let _ARM64_INS_UMLAL2 = 1170;;
let _ARM64_INS_UMLALB = 1171;;
let _ARM64_INS_UMLALT = 1172;;
let _ARM64_INS_UMLSL = 1173;;
let _ARM64_INS_UMLSL2 = 1174;;
let _ARM64_INS_UMLSLB = 1175;;
let _ARM64_INS_UMLSLT = 1176;;
let _ARM64_INS_UMMLA = 1177;;
let _ARM64_INS_UMNEGL = 1178;;
let _ARM64_INS_UMOPA = 1179;;
let _ARM64_INS_UMOPS = 1180;;
let _ARM64_INS_UMOV = 1181;;
let _ARM64_INS_UMSUBL = 1182;;
let _ARM64_INS_UMULH = 1183;;
let _ARM64_INS_UMULL = 1184;;
let _ARM64_INS_UMULL2 = 1185;;
let _ARM64_INS_UMULLB = 1186;;
let _ARM64_INS_UMULLT = 1187;;
let _ARM64_INS_UQADD = 1188;;
let _ARM64_INS_UQDECB = 1189;;
let _ARM64_INS_UQDECD = 1190;;
let _ARM64_INS_UQDECH = 1191;;
let _ARM64_INS_UQDECP = 1192;;
let _ARM64_INS_UQDECW = 1193;;
let _ARM64_INS_UQINCB = 1194;;
let _ARM64_INS_UQINCD = 1195;;
let _ARM64_INS_UQINCH = 1196;;
let _ARM64_INS_UQINCP = 1197;;
let _ARM64_INS_UQINCW = 1198;;
let _ARM64_INS_UQRSHL = 1199;;
let _ARM64_INS_UQRSHLR = 1200;;
let _ARM64_INS_UQRSHRN = 1201;;
let _ARM64_INS_UQRSHRN2 = 1202;;
let _ARM64_INS_UQRSHRNB = 1203;;
let _ARM64_INS_UQRSHRNT = 1204;;
let _ARM64_INS_UQSHL = 1205;;
let _ARM64_INS_UQSHLR = 1206;;
let _ARM64_INS_UQSHRN = 1207;;
let _ARM64_INS_UQSHRN2 = 1208;;
let _ARM64_INS_UQSHRNB = 1209;;
let _ARM64_INS_UQSHRNT = 1210;;
let _ARM64_INS_UQSUB = 1211;;
let _ARM64_INS_UQSUBR = 1212;;
let _ARM64_INS_UQXTN = 1213;;
let _ARM64_INS_UQXTN2 = 1214;;
let _ARM64_INS_UQXTNB = 1215;;
let _ARM64_INS_UQXTNT = 1216;;
let _ARM64_INS_URECPE = 1217;;
let _ARM64_INS_URHADD = 1218;;
let _ARM64_INS_URSHL = 1219;;
let _ARM64_INS_URSHLR = 1220;;
let _ARM64_INS_URSHR = 1221;;
let _ARM64_INS_URSQRTE = 1222;;
let _ARM64_INS_URSRA = 1223;;
let _ARM64_INS_USDOT = 1224;;
let _ARM64_INS_USHL = 1225;;
let _ARM64_INS_USHLL = 1226;;
let _ARM64_INS_USHLL2 = 1227;;
let _ARM64_INS_USHLLB = 1228;;
let _ARM64_INS_USHLLT = 1229;;
let _ARM64_INS_USHR = 1230;;
let _ARM64_INS_USMMLA = 1231;;
let _ARM64_INS_USMOPA = 1232;;
let _ARM64_INS_USMOPS = 1233;;
let _ARM64_INS_USQADD = 1234;;
let _ARM64_INS_USRA = 1235;;
let _ARM64_INS_USUBL = 1236;;
let _ARM64_INS_USUBL2 = 1237;;
let _ARM64_INS_USUBLB = 1238;;
let _ARM64_INS_USUBLT = 1239;;
let _ARM64_INS_USUBW = 1240;;
let _ARM64_INS_USUBW2 = 1241;;
let _ARM64_INS_USUBWB = 1242;;
let _ARM64_INS_USUBWT = 1243;;
let _ARM64_INS_UUNPKHI = 1244;;
let _ARM64_INS_UUNPKLO = 1245;;
let _ARM64_INS_UXTB = 1246;;
let _ARM64_INS_UXTH = 1247;;
let _ARM64_INS_UXTL = 1248;;
let _ARM64_INS_UXTL2 = 1249;;
let _ARM64_INS_UXTW = 1250;;
let _ARM64_INS_UZP1 = 1251;;
let _ARM64_INS_UZP2 = 1252;;
let _ARM64_INS_WFE = 1253;;
let _ARM64_INS_WFET = 1254;;
let _ARM64_INS_WFI = 1255;;
let _ARM64_INS_WFIT = 1256;;
let _ARM64_INS_WHILEGE = 1257;;
let _ARM64_INS_WHILEGT = 1258;;
let _ARM64_INS_WHILEHI = 1259;;
let _ARM64_INS_WHILEHS = 1260;;
let _ARM64_INS_WHILELE = 1261;;
let _ARM64_INS_WHILELO = 1262;;
let _ARM64_INS_WHILELS = 1263;;
let _ARM64_INS_WHILELT = 1264;;
let _ARM64_INS_WHILERW = 1265;;
let _ARM64_INS_WHILEWR = 1266;;
let _ARM64_INS_WRFFR = 1267;;
let _ARM64_INS_XAFLAG = 1268;;
let _ARM64_INS_XAR = 1269;;
let _ARM64_INS_XPACD = 1270;;
let _ARM64_INS_XPACI = 1271;;
let _ARM64_INS_XPACLRI = 1272;;
let _ARM64_INS_XTN = 1273;;
let _ARM64_INS_XTN2 = 1274;;
let _ARM64_INS_YIELD = 1275;;
let _ARM64_INS_ZERO = 1276;;
let _ARM64_INS_ZIP1 = 1277;;
let _ARM64_INS_ZIP2 = 1278;;
let _ARM64_INS_SBFIZ = 1279;;
let _ARM64_INS_UBFIZ = 1280;;
let _ARM64_INS_SBFX = 1281;;
let _ARM64_INS_UBFX = 1282;;
let _ARM64_INS_BFI = 1283;;
let _ARM64_INS_BFXIL = 1284;;
let _ARM64_INS_IC = 1285;;
let _ARM64_INS_DC = 1286;;
let _ARM64_INS_AT = 1287;;
let _ARM64_INS_TLBI = 1288;;
let _ARM64_INS_ENDING = 1289;;

let _ARM64_GRP_INVALID = 0;;
let _ARM64_GRP_JUMP = 1;;
let _ARM64_GRP_CALL = 2;;
let _ARM64_GRP_RET = 3;;
let _ARM64_GRP_INT = 4;;
let _ARM64_GRP_PRIVILEGE = 6;;
let _ARM64_GRP_BRANCH_RELATIVE = 7;;
let _ARM64_GRP_PAC = 8;;
let _ARM64_GRP_CRYPTO = 128;;
let _ARM64_GRP_FPARMV8 = 129;;
let _ARM64_GRP_NEON = 130;;
let _ARM64_GRP_CRC = 131;;
let _ARM64_GRP_AES = 132;;
let _ARM64_GRP_DOTPROD = 133;;
let _ARM64_GRP_FULLFP16 = 134;;
let _ARM64_GRP_LSE = 135;;
let _ARM64_GRP_RCPC = 136;;
let _ARM64_GRP_RDM = 137;;
let _ARM64_GRP_SHA2 = 138;;
let _ARM64_GRP_SHA3 = 139;;
let _ARM64_GRP_SM4 = 140;;
let _ARM64_GRP_SVE = 141;;
let _ARM64_GRP_SVE2 = 142;;
let _ARM64_GRP_SVE2AES = 143;;
let _ARM64_GRP_SVE2BitPerm = 144;;
let _ARM64_GRP_SVE2SHA3 = 145;;
let _ARM64_GRP_SVE2SM4 = 146;;
let _ARM64_GRP_SME = 147;;
let _ARM64_GRP_SMEF64 = 148;;
let _ARM64_GRP_SMEI64 = 149;;
let _ARM64_GRP_MatMulFP32 = 150;;
let _ARM64_GRP_MatMulFP64 = 151;;
let _ARM64_GRP_MatMulInt8 = 152;;
let _ARM64_GRP_V8_1A = 153;;
let _ARM64_GRP_V8_3A = 154;;
let _ARM64_GRP_V8_4A = 155;;
let _ARM64_GRP_ENDING = 156;;
